@@ -10,6 +10,18 @@
 const char DATA_DATABASE_SQLITE3_MAGIC[16]
     = {0x53, 0x51, 0x4c, 0x69, 0x74, 0x65, 0x20, 0x66, 0x6f, 0x72, 0x6d, 0x61, 0x74, 0x20, 0x33, 0x00 };
 
+/*!
+ *  \brief string constant to create an sql database table
+ *
+ *  This table contains head values
+ */
+static const char *DATA_DATABASE_CREATE_HEAD_TABLE =
+    "CREATE TABLE IF NOT EXISTS head ( "
+        "id INTEGER NOT NULL PRIMARY KEY ASC, "
+        "key TEXT NOT NULL UNIQUE, "
+        "value TEXT NOT NULL"
+    ");";
+
 /*!
  *  \brief string constant to create an sql database table
  *
@@ -31,29 +43,6 @@ static const char *DATA_DATABASE_CREATE_CLASSIFIER_TABLE =
         "uuid TEXT NOT NULL DEFAULT \'\'"  /* DEFAULT needed in case a new DB is modified by an old program version */
     ");";
 
-/*!
- *  \brief string constant to create an sql database index
- */
-/*
-static const char *DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX =
-    "CREATE INDEX IF NOT EXISTS classifier_ordering ON classifiers ( "
-        "y_order ASC, "
-        "x_order ASC "
-    ");";
-*/
-
-#if 0
-/*!
- *  \brief string constant to update an sql database table
- *
- *  This command extends classifiers by list_order field.
- *  \see http://sqlite.org/lang_altertable.html
- */
-static const char *DATA_DATABASE_ALTER_CLASSIFIER_TABLE_1 =
-    "ALTER TABLE classifiers "
-    "ADD COLUMN list_order INTEGER;";
-#endif
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -61,6 +50,7 @@ static const char *DATA_DATABASE_ALTER_CLASSIFIER_TABLE_1 =
  *  and in case a new database is modified by an old program version.
  *
  *  This command extends classifiers by a uuid field.
+ *  \see http://sqlite.org/lang_altertable.html
  */
 static const char *DATA_DATABASE_ALTER_CLASSIFIER_TABLE_UUID =
     "ALTER TABLE classifiers "
@@ -105,43 +95,6 @@ static const char *DATA_DATABASE_CREATE_RELATIONSHIP_TABLE =
         "FOREIGN KEY(to_feature_id) REFERENCES features(id) "
     ");";
 
-/*!
- *  \brief string constant to create an sql database index
- */
-/*
-static const char *DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX =
-    "CREATE INDEX IF NOT EXISTS relationship_ordering ON relationships ( "
-        "list_order ASC "
-    ");";
-*/
-
-#if 0
-/*!
- *  \brief string constant to update an sql database table
- *
- *  The DEFAULT clause is needed to convert the existing records to the new format
- *  and in case a new database is modified by an old program version.
- *
- *  This command extends relationships by from_feature_id field.
- *  \see http://sqlite.org/lang_altertable.html
- */
-static const char *DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_1 =
-    "ALTER TABLE relationships "
-    "ADD COLUMN from_feature_id INTEGER DEFAULT NULL;";
-
-/*!
- *  \brief string constant to update an sql database table
- *
- *  The DEFAULT clause is needed to convert the existing records to the new format
- *  and in case a new database is modified by an old program version.
- *
- *  This command extends relationships by to_feature_id field.
- */
-static const char *DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_2 =
-    "ALTER TABLE relationships "
-    "ADD COLUMN to_feature_id INTEGER DEFAULT NULL;";
-#endif
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -194,16 +147,6 @@ static const char *DATA_DATABASE_CREATE_FEATURE_TABLE =
         "FOREIGN KEY(classifier_id) REFERENCES classifiers(id) "
     ");";
 
-/*!
- *  \brief string constant to create an sql database index
- */
-/*
-static const char *DATA_DATABASE_CREATE_FEATUREORDERING_INDEX =
-    "CREATE INDEX IF NOT EXISTS feature_ordering ON features ( "
-        "list_order ASC "
-    ");";
-*/
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -242,16 +185,6 @@ static const char *DATA_DATABASE_CREATE_DIAGRAM_TABLE =
         "FOREIGN KEY(parent_id) REFERENCES diagrams(id) "
     ");";
 
-/*!
- *  \brief string constant to create an sql database index
- */
-/*
-static const char *DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX =
-    "CREATE INDEX IF NOT EXISTS diagram_ordering ON diagrams ( "
-        "list_order ASC "
-    ");";
-*/
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -285,16 +218,6 @@ static const char *DATA_DATABASE_ALTER_DIAGRAM_TABLE_UUID =
 static const char *DATA_DATABASE_UPDATE_DIAGRAM_UUID =
     "UPDATE diagrams SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE diagrams.id!=-1) WHERE uuid=\'\';";
 
-#if 0
-/*!
- *  \brief string constant to update an sql database table
- *
- *  The root diagram is marked by parent_id = NULL, not by -1 anymore.
- */
-static const char *DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT =
-    "UPDATE diagrams SET parent_id=NULL WHERE parent_id=-1;";
-#endif
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -320,23 +243,9 @@ static const char *DATA_DATABASE_CREATE_DIAGRAMELEMENT_TABLE =
         "uuid TEXT NOT NULL DEFAULT \'\', "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "FOREIGN KEY(diagram_id) REFERENCES diagrams(id), "
         "FOREIGN KEY(classifier_id) REFERENCES classifiers(id), "
-        "FOREIGN KEY(focused_feature_id) REFERENCES feature(id) "
+        "FOREIGN KEY(focused_feature_id) REFERENCES features(id) "
     ");";
 
-#if 0
-/*!
- *  \brief string constant to update an sql database table
- *
- *  The DEFAULT clause is needed to convert the existing records to the new format.
- *
- *  This command extends diagramelements by to_feature_id field.
- *  \see http://sqlite.org/lang_altertable.html
- */
-static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_1 =
-    "ALTER TABLE diagramelements "
-    "ADD COLUMN focused_feature_id INTEGER DEFAULT NULL;";
-#endif
-
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -374,86 +283,7 @@ static const char *DATA_DATABASE_BEGIN_TRANSACTION =
 static const char *DATA_DATABASE_COMMIT_TRANSACTION =
     "COMMIT TRANSACTION;";
 
-u8_error_t data_database_private_initialize_tables( data_database_t *this_ )
-{
-    U8_TRACE_BEGIN();
-    u8_error_t result = U8_ERROR_NONE;
-
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_CLASSIFIER_TABLE, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_RELATIONSHIP_TABLE, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_FEATURE_TABLE, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAM_TABLE, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAMELEMENT_TABLE, false );
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
-u8_error_t data_database_private_initialize_indexes( data_database_t *this_ )
-{
-    U8_TRACE_BEGIN();
-    u8_error_t result = U8_ERROR_NONE;
-
-    /*
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_FEATUREORDERING_INDEX, false );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX, false );
-    */
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
-u8_error_t data_database_private_upgrade_tables( data_database_t *this_ )
-{
-    U8_TRACE_BEGIN();
-    u8_error_t result = U8_ERROR_NONE;
-
-#if 0
-    /* update table relationships from version 1.0.0 to later versions */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_1, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_2, true );
-
-    /* update table diagramelements from version 1.0.0 to later versions */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_1, true );
-
-    /* update table diagrams from version 1.0.0 to later versions */
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT, true );
-
-    /* update table classifiers from version 1.4.0 or earlier to 1.5.0 or later versions */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_CLASSIFIER_TABLE_1, true );
-#endif
-
-    /* update table classifiers from version 1.32.1 or earlier to later versions with diagram.display_flags */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_1, true );
-
-    /* update all 5 tables from version 1.32.1 (no uuid) to later versions with uuid field */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_CLASSIFIER_TABLE_UUID, true );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_CLASSIFIER_UUID, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_UUID, true );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_RELATIONSHIP_UUID, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_FEATURE_TABLE_UUID, true );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_FEATURE_UUID, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_UUID, true );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAM_UUID, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_UUID, true );
-    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAMELEMENT_UUID, true );
-
-    /* update table diagrams and relationships from version 1.46.0 or earlier to later versions with stereotype */
-    /* do not care for "already existed" errors: */
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_STEREOTYPE, true );
-    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_STEREOTYPE, true );
-
-    if ( u8_error_contains( result, U8_ERROR_READ_ONLY_DB ) )
-    {
-        U8_LOG_EVENT( "sqlite3 database is read only." );
-        result = u8_error_more_than( result, U8_ERROR_READ_ONLY_DB ) ? U8_ERROR_AT_DB : U8_ERROR_NONE;
-    }
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
+/* ================================ Lifecycle ================================ */
 
 void data_database_init ( data_database_t *this_ )
 {
@@ -464,14 +294,15 @@ void data_database_init ( data_database_t *this_ )
     (*this_).db_file_name = utf8stringbuf_init( sizeof((*this_).private_db_file_name_buffer), (*this_).private_db_file_name_buffer );
     utf8stringbuf_clear( (*this_).db_file_name );
 
-    g_mutex_init ( &((*this_).private_lock) );
+    g_mutex_init ( &((*this_).lock_on_write) );
+    (*this_).locked_on_write = false;
 
-    u8_error_t result = data_database_private_lock( this_ );
+    u8_error_t result = data_database_lock_on_write( this_ );
     {
         (*this_).db_state = DATA_DATABASE_STATE_CLOSED;
         (*this_).transaction_recursion = 0;
     }
-    result |= data_database_private_unlock( this_ );
+    result |= data_database_unlock_on_write( this_ );
     if( result != U8_ERROR_NONE )
     {
         assert(false);
@@ -493,7 +324,7 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
     u8_error_t result = U8_ERROR_NONE;
     bool notify_listeners = false;
 
-    result |= data_database_private_lock( this_ );
+    result |= data_database_lock_on_write( this_ );
 
     if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
@@ -522,10 +353,6 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
             u8_error_t init_err;
             init_err = data_database_private_initialize_tables( this_ );
             if ( init_err == U8_ERROR_NONE )
-            {
-                init_err = data_database_private_initialize_indexes( this_ );
-            }
-            if ( init_err == U8_ERROR_NONE )
             {
                 init_err = data_database_private_upgrade_tables( this_ );
             }
@@ -553,7 +380,7 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
         }
     }
 
-    result |= data_database_private_unlock( this_ );
+    result |= data_database_unlock_on_write( this_ );
 
     if ( notify_listeners )
     {
@@ -586,7 +413,8 @@ u8_error_t data_database_close ( data_database_t *this_ )
     u8_error_t result = U8_ERROR_NONE;
     bool notify_change_listeners = false;
 
-    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
+    /* do sent notifications before closing: */
+    if ( data_database_is_open( this_ ) )
     {
         /* do sent notifications when closing: */
         data_change_notifier_disable_stealth_mode( &((*this_).notifier) );
@@ -604,7 +432,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
         result |= data_database_private_notify_db_listeners( this_, DATA_DATABASE_LISTENER_SIGNAL_PREPARE_CLOSE );
     }
 
-    result |= data_database_private_lock( this_ );
+    result |= data_database_lock_on_write( this_ );
 
     if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
@@ -629,7 +457,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
         result |= U8_ERROR_INVALID_REQUEST;
     }
 
-    result |= data_database_private_unlock( this_ );
+    result |= data_database_unlock_on_write( this_ );
 
     if ( notify_change_listeners )
     {
@@ -654,33 +482,89 @@ void data_database_destroy ( data_database_t *this_ )
     assert( (*this_).transaction_recursion == 0 );
 
     data_database_private_clear_db_listener_list( this_ );
-    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
+    if ( data_database_is_open( this_ ) )
     {
         data_database_close( this_ );
     }
     data_change_notifier_destroy( &((*this_).notifier) );
 
-    u8_error_t result = data_database_private_lock( this_ );
+    u8_error_t result = data_database_lock_on_write( this_ );
     {
         (*this_).transaction_recursion = 0;
     }
-    result |= data_database_private_unlock( this_ );
+    result |= data_database_unlock_on_write( this_ );
     if( result != U8_ERROR_NONE )
     {
         assert(false);
     }
 
-    /* g_mutex_clear ( &((*this_).private_lock) ); -- must not be called because this GMutex is not on the stack */
+    /* g_mutex_clear ( &((*this_).lock_on_write) ); -- must not be called because this GMutex is not on the stack */
 
     U8_TRACE_END();
 }
 
+u8_error_t data_database_private_initialize_tables( data_database_t *this_ )
+{
+    U8_TRACE_BEGIN();
+    u8_error_t result = U8_ERROR_NONE;
+
+    /* since the database is locked during data_database_private_initialize_tables */
+    /* we cannot call data_database_transaction_begin or data_database_in_transaction_execute here */
+
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_HEAD_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_CLASSIFIER_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_RELATIONSHIP_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_FEATURE_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAM_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAMELEMENT_TABLE, false );
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+u8_error_t data_database_private_upgrade_tables( data_database_t *this_ )
+{
+    U8_TRACE_BEGIN();
+    u8_error_t result = U8_ERROR_NONE;
+
+    /* update table classifiers from version 1.32.1 or earlier to later versions with diagram.display_flags */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_1, true );
+
+    /* update all 5 tables from version 1.32.1 (no uuid) to later versions with uuid field */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_CLASSIFIER_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_CLASSIFIER_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_RELATIONSHIP_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_FEATURE_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_FEATURE_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAM_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAMELEMENT_UUID, true );
+
+    /* update table diagrams and relationships from version 1.46.0 or earlier to later versions with stereotype */
+    /* do not care for "already existed" errors: */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_STEREOTYPE, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_STEREOTYPE, true );
+
+    if ( u8_error_contains( result, U8_ERROR_READ_ONLY_DB ) )
+    {
+        U8_LOG_EVENT( "sqlite3 database is read only." );
+        result = u8_error_more_than( result, U8_ERROR_READ_ONLY_DB ) ? U8_ERROR_AT_DB : U8_ERROR_NONE;
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+/* ================================ Actions on DB ================================ */
+
 u8_error_t data_database_flush_caches ( data_database_t *this_ )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
 
-    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
+    if ( data_database_is_open( this_ ) )
     {
         U8_LOG_EVENT_INT( "sqlite3_libversion_number()", sqlite3_libversion_number() );
         if ( sqlite3_libversion_number() >= 3010000 )
@@ -718,7 +602,7 @@ u8_error_t data_database_trace_stats ( data_database_t *this_ )
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
 
-    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
+    if ( data_database_is_open( this_ ) )
     {
         sqlite3_int64 use;
         sqlite3_int64 max;
@@ -736,105 +620,6 @@ u8_error_t data_database_trace_stats ( data_database_t *this_ )
     return result;
 }
 
-u8_error_t data_database_add_db_listener( data_database_t *this_, data_database_listener_t *listener )
-{
-    U8_TRACE_BEGIN();
-    assert( NULL != listener );
-    u8_error_t result = U8_ERROR_NONE;
-    bool already_registered = false;
-
-    result |= data_database_private_lock( this_ );
-
-    int pos = -1;
-    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
-    {
-        if ( NULL == (*this_).listener_list[index] )
-        {
-            pos = index;
-        }
-        if ( listener == (*this_).listener_list[index] )
-        {
-            already_registered = true;
-        }
-    }
-
-    if ( already_registered )
-    {
-        U8_LOG_ERROR( "Listener already registered." );
-        result |= U8_ERROR_INVALID_REQUEST;
-    }
-    else if ( -1 != pos )
-    {
-        (*this_).listener_list[pos] = listener;
-    }
-    else
-    {
-        U8_LOG_ERROR_INT( "Maximum number of listeners reached.", DATA_DATABASE_MAX_LISTENERS );
-        result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
-    }
-
-    result |= data_database_private_unlock( this_ );
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
-u8_error_t data_database_remove_db_listener( data_database_t *this_, data_database_listener_t *listener )
-{
-    U8_TRACE_BEGIN();
-
-    assert( NULL != listener );
-
-    u8_error_t result = U8_ERROR_NONE;
-    int count_closed = 0;
-
-    result |= data_database_private_lock( this_ );
-
-    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
-    {
-        if ( (*this_).listener_list[index] == listener )
-        {
-            (*this_).listener_list[index] = NULL;
-            count_closed ++;
-        }
-    }
-
-    result |= data_database_private_unlock( this_ );
-
-    if ( count_closed == 0 )
-    {
-        U8_LOG_ERROR( "listener not found" );
-        result |= U8_ERROR_INVALID_REQUEST;
-    }
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
-u8_error_t data_database_private_notify_db_listeners( data_database_t *this_, data_database_listener_signal_t signal_id )
-{
-    U8_TRACE_BEGIN();
-    data_database_listener_t *(listener_list_copy[DATA_DATABASE_MAX_LISTENERS]);
-    u8_error_t result = U8_ERROR_NONE;
-
-    result |= data_database_private_lock( this_ );
-
-    memcpy( listener_list_copy, (*this_).listener_list, sizeof(listener_list_copy) );
-
-    result |= data_database_private_unlock( this_ );
-
-    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
-    {
-        if ( NULL != listener_list_copy[index] )
-        {
-            data_database_listener_notify( listener_list_copy[index], signal_id );
-        }
-    }
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
 u8_error_t data_database_transaction_begin ( data_database_t *this_ )
 {
     U8_TRACE_BEGIN();
@@ -917,9 +702,216 @@ u8_error_t data_database_transaction_commit ( data_database_t *this_ )
     return result;
 }
 
+u8_error_t data_database_in_transaction_create ( data_database_t *this_, const char* sql_statement, data_row_id_t* out_new_id )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != sql_statement );
+    u8_error_t result = U8_ERROR_NONE;
+    int sqlite_err;
+    char *error_msg = NULL;
+    sqlite3 *const db = (*this_).db;
+
+    if ( data_database_is_open( this_ ) )
+    {
+        U8_LOG_EVENT( "sqlite3_exec: sql_statement (see trace)" );
+        U8_TRACE_INFO_STR( "sqlite3_exec:", sql_statement );
+        sqlite_err = sqlite3_exec( db, sql_statement, NULL, NULL, &error_msg );
+        if ( SQLITE_CONSTRAINT == (0xff & sqlite_err) )
+        {
+            /* This case happens if id is not unique and/or if a classifier name is not unique*/
+            U8_LOG_ERROR( "sqlite3_exec() failed due to UNIQUE constraint: sql_statement (see trace)" );
+            U8_TRACE_INFO_STR( "sqlite3_exec() failed due to UNIQUE constraint:", sql_statement );
+            result |= U8_ERROR_DUPLICATE;
+        }
+        else if ( SQLITE_OK != sqlite_err )
+        {
+            U8_LOG_ERROR( "sqlite3_exec() failed: sql_statement (see trace)" );
+            U8_LOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
+            U8_TRACE_INFO_STR( "sqlite3_exec:", sql_statement );
+            result |= (sqlite_err == SQLITE_READONLY) ? U8_ERROR_READ_ONLY_DB : U8_ERROR_AT_DB;
+        }
+        if ( error_msg != NULL )
+        {
+            U8_LOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
+            sqlite3_free( error_msg );
+            error_msg = NULL;
+        }
+
+        if ( NULL != out_new_id )
+        {
+            if ( SQLITE_OK == sqlite_err )
+            {
+                data_row_id_t new_id;
+                new_id = sqlite3_last_insert_rowid(db);
+                U8_LOG_EVENT_INT( "sqlite3_last_insert_rowid():", new_id );
+                *out_new_id = new_id;
+            }
+        }
+    }
+    else
+    {
+        U8_LOG_WARNING( "database not open. cannot execute sql_statement (see trace)" );
+        U8_TRACE_INFO_STR( "database not open. cannot execute", sql_statement );
+        result = U8_ERROR_NO_DB;
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+u8_error_t data_database_in_transaction_execute ( data_database_t *this_, const char* sql_statement )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != sql_statement );
+    u8_error_t result = U8_ERROR_NONE;
+    int sqlite_err;
+    char *error_msg = NULL;
+    sqlite3 *db = (*this_).db;
+
+    if ( data_database_is_open( this_ ) )
+    {
+        U8_LOG_EVENT( "sqlite3_exec: sql_statement (see trace)" );
+        U8_TRACE_INFO_STR( "sqlite3_exec:", sql_statement );
+        sqlite_err = sqlite3_exec( db, sql_statement, NULL, NULL, &error_msg );
+        if ( SQLITE_CONSTRAINT == (0xff & sqlite_err) )
+        {
+            U8_LOG_ERROR( "sqlite3_exec() failed due to UNIQUE constraint: sql_statement (see trace)" );
+            U8_TRACE_INFO_STR( "sqlite3_exec() failed due to UNIQUE constraint:", sql_statement );
+            result |= U8_ERROR_DUPLICATE_NAME;
+        }
+        else if ( SQLITE_OK != sqlite_err )
+        {
+            U8_LOG_ERROR( "sqlite3_exec() failed: sql_statement (see trace)" );
+            U8_LOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
+            U8_TRACE_INFO_STR( "sqlite3_exec() failed:", sql_statement );
+            result |= (sqlite_err == SQLITE_READONLY) ? U8_ERROR_READ_ONLY_DB : U8_ERROR_AT_DB;
+        }
+        if ( error_msg != NULL )
+        {
+            U8_LOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
+            sqlite3_free( error_msg );
+            error_msg = NULL;
+        }
+    }
+    else
+    {
+        U8_LOG_WARNING( "database not open. cannot execute sql_statement (see trace)" );
+        U8_TRACE_INFO_STR( "database not open. cannot execute", sql_statement );
+        result = U8_ERROR_NO_DB;
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+/* ================================ Information ================================ */
+
+/* ================================ Change Listener ================================ */
+
+u8_error_t data_database_add_db_listener( data_database_t *this_, data_database_listener_t *listener )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != listener );
+    u8_error_t result = U8_ERROR_NONE;
+    bool already_registered = false;
+
+    result |= data_database_lock_on_write( this_ );
+
+    int pos = -1;
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
+    {
+        if ( NULL == (*this_).listener_list[index] )
+        {
+            pos = index;
+        }
+        if ( listener == (*this_).listener_list[index] )
+        {
+            already_registered = true;
+        }
+    }
+
+    if ( already_registered )
+    {
+        U8_LOG_ERROR( "Listener already registered." );
+        result |= U8_ERROR_INVALID_REQUEST;
+    }
+    else if ( -1 != pos )
+    {
+        (*this_).listener_list[pos] = listener;
+    }
+    else
+    {
+        U8_LOG_ERROR_INT( "Maximum number of listeners reached.", DATA_DATABASE_MAX_LISTENERS );
+        result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
+    }
+
+    result |= data_database_unlock_on_write( this_ );
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+u8_error_t data_database_remove_db_listener( data_database_t *this_, data_database_listener_t *listener )
+{
+    U8_TRACE_BEGIN();
+
+    assert( NULL != listener );
+
+    u8_error_t result = U8_ERROR_NONE;
+    int count_closed = 0;
+
+    result |= data_database_lock_on_write( this_ );
+
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
+    {
+        if ( (*this_).listener_list[index] == listener )
+        {
+            (*this_).listener_list[index] = NULL;
+            count_closed ++;
+        }
+    }
+
+    result |= data_database_unlock_on_write( this_ );
+
+    if ( count_closed == 0 )
+    {
+        U8_LOG_ERROR( "listener not found" );
+        result |= U8_ERROR_INVALID_REQUEST;
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+u8_error_t data_database_private_notify_db_listeners( data_database_t *this_, data_database_listener_signal_t signal_id )
+{
+    U8_TRACE_BEGIN();
+    data_database_listener_t *(listener_list_copy[DATA_DATABASE_MAX_LISTENERS]);
+    u8_error_t result = U8_ERROR_NONE;
+
+    result |= data_database_lock_on_write( this_ );
+
+    memcpy( listener_list_copy, (*this_).listener_list, sizeof(listener_list_copy) );
+
+    result |= data_database_unlock_on_write( this_ );
+
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
+    {
+        if ( NULL != listener_list_copy[index] )
+        {
+            data_database_listener_notify( listener_list_copy[index], signal_id );
+        }
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
+/* ================================ Lifecycle Lock ================================ */
+
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
