@@ -174,7 +174,7 @@ u8_error_t data_database_classifier_reader_get_classifier_by_id( data_database_c
         {
             /* this situation may happen if a classifier is deleted that is shown in the attributes editor */
             U8_TRACE_INFO_INT( "sqlite3_step did not find a row for id", id );
-            result |= U8_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;  /* non-existing ids are worse than U8_ERROR_NOT_FOUND */
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -192,13 +192,13 @@ u8_error_t data_database_classifier_reader_get_classifier_by_id( data_database_c
                                           );
 
             data_classifier_trace( out_classifier );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -245,13 +245,13 @@ u8_error_t data_database_classifier_reader_get_classifier_by_name( data_database
                                           );
 
             data_classifier_trace( out_classifier );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -299,13 +299,13 @@ u8_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_databas
                                           );
 
             data_classifier_trace( out_classifier );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -514,7 +514,7 @@ u8_error_t data_database_classifier_reader_get_feature_by_id ( data_database_cla
         if ( SQLITE_ROW != sqlite_err )
         {
             U8_TRACE_INFO_INT( "sqlite3_step did not find a row for id", id );
-            result |= U8_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;  /* non-existing ids are worse than U8_ERROR_NOT_FOUND */
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -531,13 +531,13 @@ u8_error_t data_database_classifier_reader_get_feature_by_id ( data_database_cla
                                        );
 
             data_feature_trace( out_feature );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -584,13 +584,13 @@ u8_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database_c
                                        );
 
             data_feature_trace( out_feature );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -868,7 +868,7 @@ u8_error_t data_database_classifier_reader_get_relationship_by_id ( data_databas
         if ( SQLITE_ROW != sqlite_err )
         {
             U8_TRACE_INFO_INT( "sqlite3_step did not find a row for id", id );
-            result |= U8_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;  /* non-existing ids are worse than U8_ERROR_NOT_FOUND */
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -896,13 +896,13 @@ u8_error_t data_database_classifier_reader_get_relationship_by_id ( data_databas
             }
 
             data_relationship_trace( out_relationship );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -960,13 +960,13 @@ u8_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_datab
             }
 
             data_relationship_trace( out_relationship );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -1209,83 +1209,83 @@ u8_error_t data_database_classifier_reader_private_open ( data_database_classifi
     u8_error_t result = U8_ERROR_NONE;
 
     {
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_ID ),
-                                                                              &((*this_).statement_classifier_by_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_ID ),
+                                                   &((*this_).statement_classifier_by_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_UUID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_UUID ),
-                                                                              &((*this_).statement_classifier_by_uuid)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_UUID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_UUID ),
+                                                   &((*this_).statement_classifier_by_uuid)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_NAME,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_NAME ),
-                                                                              &((*this_).statement_classifier_by_name)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_NAME,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIER_BY_NAME ),
+                                                   &((*this_).statement_classifier_by_name)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_CLASSIFIERS_BY_DIAGRAM_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIERS_BY_DIAGRAM_ID ),
-                                                                              &((*this_).statement_classifiers_by_diagram_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_CLASSIFIERS_BY_DIAGRAM_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_CLASSIFIERS_BY_DIAGRAM_ID ),
+                                                   &((*this_).statement_classifiers_by_diagram_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_FEATURE_BY_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_FEATURE_BY_ID ),
-                                                                              &((*this_).statement_feature_by_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_FEATURE_BY_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_FEATURE_BY_ID ),
+                                                   &((*this_).statement_feature_by_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_FEATURE_BY_UUID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_FEATURE_BY_UUID ),
-                                                                              &((*this_).statement_feature_by_uuid)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_FEATURE_BY_UUID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_FEATURE_BY_UUID ),
+                                                   &((*this_).statement_feature_by_uuid)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_FEATURES_BY_CLASSIFIER_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_FEATURES_BY_CLASSIFIER_ID ),
-                                                                              &((*this_).statement_features_by_classifier_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_FEATURES_BY_CLASSIFIER_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_FEATURES_BY_CLASSIFIER_ID ),
+                                                   &((*this_).statement_features_by_classifier_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_FEATURES_BY_DIAGRAM_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_FEATURES_BY_DIAGRAM_ID ),
-                                                                              &((*this_).statement_features_by_diagram_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_FEATURES_BY_DIAGRAM_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_FEATURES_BY_DIAGRAM_ID ),
+                                                   &((*this_).statement_features_by_diagram_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_ID ),
-                                                                              &((*this_).statement_relationship_by_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_ID ),
+                                                   &((*this_).statement_relationship_by_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_UUID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_UUID ),
-                                                                              &((*this_).statement_relationship_by_uuid)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_UUID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIP_BY_UUID ),
+                                                   &((*this_).statement_relationship_by_uuid)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_CLASSIFIER_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_CLASSIFIER_ID ),
-                                                                              &((*this_).statement_relationships_by_classifier_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_CLASSIFIER_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_CLASSIFIER_ID ),
+                                                   &((*this_).statement_relationships_by_classifier_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_FEATURE_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_FEATURE_ID ),
-                                                                              &((*this_).statement_relationships_by_feature_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_FEATURE_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_FEATURE_ID ),
+                                                   &((*this_).statement_relationships_by_feature_id)
+                                                 );
 
-        result |= data_database_classifier_reader_private_prepare_statement ( this_,
-                                                                              DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_DIAGRAM_ID,
-                                                                              sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_DIAGRAM_ID ),
-                                                                              &((*this_).statement_relationships_by_diagram_id)
-                                                                            );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_DIAGRAM_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_RELATIONSHIPS_BY_DIAGRAM_ID ),
+                                                   &((*this_).statement_relationships_by_diagram_id)
+                                                 );
 
         if ( result != U8_ERROR_NONE )
         {
@@ -1303,43 +1303,43 @@ u8_error_t data_database_classifier_reader_private_close ( data_database_classif
     u8_error_t result = U8_ERROR_NONE;
 
     {
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_classifier_by_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_classifier_by_id );
         (*this_).statement_classifier_by_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_classifier_by_name );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_classifier_by_name );
         (*this_).statement_classifier_by_name = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_classifier_by_uuid );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_classifier_by_uuid );
         (*this_).statement_classifier_by_uuid = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_classifiers_by_diagram_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_classifiers_by_diagram_id );
         (*this_).statement_classifiers_by_diagram_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_feature_by_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_feature_by_id );
         (*this_).statement_feature_by_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_feature_by_uuid );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_feature_by_uuid );
         (*this_).statement_feature_by_uuid = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_features_by_classifier_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_features_by_classifier_id );
         (*this_).statement_features_by_classifier_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_features_by_diagram_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_features_by_diagram_id );
         (*this_).statement_features_by_diagram_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_relationship_by_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_relationship_by_id );
         (*this_).statement_relationship_by_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_relationship_by_uuid );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_relationship_by_uuid );
         (*this_).statement_relationship_by_uuid = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_relationships_by_classifier_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_relationships_by_classifier_id );
         (*this_).statement_relationships_by_classifier_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_relationships_by_feature_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_relationships_by_feature_id );
         (*this_).statement_relationships_by_feature_id = NULL;
 
-        result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).statement_relationships_by_diagram_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_relationships_by_diagram_id );
         (*this_).statement_relationships_by_diagram_id = NULL;
     }
 
@@ -1349,7 +1349,7 @@ u8_error_t data_database_classifier_reader_private_close ( data_database_classif
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
