@@ -202,13 +202,13 @@ u8_error_t data_database_diagram_reader_get_diagram_by_id ( data_database_diagra
             }
 
             data_diagram_trace( out_diagram );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -260,13 +260,13 @@ u8_error_t data_database_diagram_reader_get_diagram_by_uuid ( data_database_diag
             }
 
             data_diagram_trace( out_diagram );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -622,13 +622,13 @@ u8_error_t data_database_diagram_reader_get_diagramelement_by_id ( data_database
             }
 
             data_diagramelement_trace( out_diagramelement );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -677,13 +677,13 @@ u8_error_t data_database_diagram_reader_get_diagramelement_by_uuid ( data_databa
             }
 
             data_diagramelement_trace( out_diagramelement );
-        }
 
-        sqlite_err = sqlite3_step( prepared_statement );
-        if ( SQLITE_DONE != sqlite_err )
-        {
-            U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
-            result |= U8_ERROR_DB_STRUCTURE;
+            sqlite_err = sqlite3_step( prepared_statement );
+            if ( SQLITE_DONE != sqlite_err )
+            {
+                U8_LOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+                result |= U8_ERROR_DB_STRUCTURE;
+            }
         }
     }
 
@@ -829,77 +829,77 @@ u8_error_t data_database_diagram_reader_private_open ( data_database_diagram_rea
     u8_error_t result = U8_ERROR_NONE;
 
     {
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAM_BY_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_BY_ID ),
-                                                                           &((*this_).statement_diagram_by_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAM_BY_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_BY_ID ),
+                                                   &((*this_).statement_diagram_by_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAM_BY_UUID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_BY_UUID ),
-                                                                           &((*this_).statement_diagram_by_uuid)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAM_BY_UUID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_BY_UUID ),
+                                                   &((*this_).statement_diagram_by_uuid)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID ),
-                                                                           &((*this_).statement_diagrams_by_parent_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID ),
+                                                   &((*this_).statement_diagrams_by_parent_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID_NULL,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID_NULL ),
-                                                                           &((*this_).statement_diagrams_by_parent_id_null)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID_NULL,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_PARENT_ID_NULL ),
+                                                   &((*this_).statement_diagrams_by_parent_id_null)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_CLASSIFIER_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_CLASSIFIER_ID ),
-                                                                           &((*this_).statement_diagrams_by_classifier_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_CLASSIFIER_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMS_BY_CLASSIFIER_ID ),
+                                                   &((*this_).statement_diagrams_by_classifier_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID ),
-                                                                           &((*this_).statement_diagram_ids_by_parent_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID ),
+                                                   &((*this_).statement_diagram_ids_by_parent_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID_NULL,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID_NULL ),
-                                                                           &((*this_).statement_diagram_ids_by_parent_id_null)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID_NULL,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_PARENT_ID_NULL ),
+                                                   &((*this_).statement_diagram_ids_by_parent_id_null)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_CLASSIFIER_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_CLASSIFIER_ID ),
-                                                                           &((*this_).statement_diagram_ids_by_classifier_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_CLASSIFIER_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAM_IDS_BY_CLASSIFIER_ID ),
+                                                   &((*this_).statement_diagram_ids_by_classifier_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_ID ),
-                                                                           &((*this_).statement_diagramelement_by_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_ID ),
+                                                   &((*this_).statement_diagramelement_by_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_UUID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_UUID ),
-                                                                           &((*this_).statement_diagramelement_by_uuid)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_UUID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENT_BY_UUID ),
+                                                   &((*this_).statement_diagramelement_by_uuid)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_DIAGRAM_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_DIAGRAM_ID ),
-                                                                           &((*this_).statement_diagramelements_by_diagram_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_DIAGRAM_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_DIAGRAM_ID ),
+                                                   &((*this_).statement_diagramelements_by_diagram_id)
+                                                 );
 
-        result |= data_database_diagram_reader_private_prepare_statement ( this_,
-                                                                           DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_CLASSIFIER_ID,
-                                                                           sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_CLASSIFIER_ID ),
-                                                                           &((*this_).statement_diagramelements_by_classifier_id)
-                                                                         );
+        result |= data_database_prepare_statement( (*this_).database,
+                                                   DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_CLASSIFIER_ID,
+                                                   sizeof( DATA_DATABASE_READER_SELECT_DIAGRAMELEMENTS_BY_CLASSIFIER_ID ),
+                                                   &((*this_).statement_diagramelements_by_classifier_id)
+                                                 );
 
         if ( result != U8_ERROR_NONE )
         {
@@ -917,40 +917,40 @@ u8_error_t data_database_diagram_reader_private_close ( data_database_diagram_re
     u8_error_t result = U8_ERROR_NONE;
 
     {
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagram_by_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagram_by_id );
         (*this_).statement_diagram_by_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagram_by_uuid );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagram_by_uuid );
         (*this_).statement_diagram_by_uuid = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagrams_by_parent_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagrams_by_parent_id );
         (*this_).statement_diagrams_by_parent_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagrams_by_parent_id_null );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagrams_by_parent_id_null );
         (*this_).statement_diagrams_by_parent_id_null = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagrams_by_classifier_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagrams_by_classifier_id );
         (*this_).statement_diagrams_by_classifier_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagram_ids_by_parent_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagram_ids_by_parent_id );
         (*this_).statement_diagram_ids_by_parent_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagram_ids_by_parent_id_null );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagram_ids_by_parent_id_null );
         (*this_).statement_diagram_ids_by_parent_id_null = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagram_ids_by_classifier_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagram_ids_by_classifier_id );
         (*this_).statement_diagram_ids_by_classifier_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagramelement_by_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagramelement_by_id );
         (*this_).statement_diagramelement_by_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagramelement_by_uuid );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagramelement_by_uuid );
         (*this_).statement_diagramelement_by_uuid = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagramelements_by_diagram_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagramelements_by_diagram_id );
         (*this_).statement_diagramelements_by_diagram_id = NULL;
 
-        result |= data_database_diagram_reader_private_finalize_statement( this_, (*this_).statement_diagramelements_by_classifier_id );
+        result |= data_database_finalize_statement( (*this_).database, (*this_).statement_diagramelements_by_classifier_id );
         (*this_).statement_diagramelements_by_classifier_id = NULL;
 
     }
@@ -961,7 +961,7 @@ u8_error_t data_database_diagram_reader_private_close ( data_database_diagram_re
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
