@@ -5,6 +5,7 @@
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
 #include "utf8stringbuf/utf8string.h"
+#include "utf8stringbuf/utf8stringview.h"
 #include <assert.h>
 
 /*!
@@ -253,12 +254,21 @@ u8_error_t data_database_sql_builder_build_update_diagram_stereotype_cmd ( data_
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_diagram_stereotype, 0, DATA_DIAGRAM_MAX_STEREOTYPE_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_diagram_stereotype ) > DATA_DIAGRAM_MAX_STEREOTYPE_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_diagram_stereotype );
+        if ( new_length <= DATA_DIAGRAM_MAX_STEREOTYPE_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_diagram_stereotype );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_diagram_stereotype, DATA_DIAGRAM_MAX_STEREOTYPE_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -292,12 +302,21 @@ u8_error_t data_database_sql_builder_build_update_diagram_name_cmd ( data_databa
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_diagram_name, 0, DATA_DIAGRAM_MAX_NAME_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_diagram_name ) > DATA_DIAGRAM_MAX_NAME_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_diagram_name );
+        if ( new_length <= DATA_DIAGRAM_MAX_NAME_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_diagram_name );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_diagram_name, DATA_DIAGRAM_MAX_NAME_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -331,12 +350,21 @@ u8_error_t data_database_sql_builder_build_update_diagram_description_cmd ( data
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_diagram_description, 0, DATA_DIAGRAM_MAX_DESCRIPTION_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_diagram_description ) > DATA_DIAGRAM_MAX_DESCRIPTION_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_diagram_description );
+        if ( new_length <= DATA_DIAGRAM_MAX_DESCRIPTION_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_diagram_description );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_diagram_description, DATA_DIAGRAM_MAX_DESCRIPTION_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -637,12 +665,21 @@ u8_error_t data_database_sql_builder_build_update_classifier_stereotype_cmd ( da
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_classifier_stereotype, 0, DATA_CLASSIFIER_MAX_STEREOTYPE_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_classifier_stereotype ) > DATA_CLASSIFIER_MAX_STEREOTYPE_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_classifier_stereotype );
+        if ( new_length <= DATA_CLASSIFIER_MAX_STEREOTYPE_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_classifier_stereotype );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_classifier_stereotype, DATA_CLASSIFIER_MAX_STEREOTYPE_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -676,12 +713,21 @@ u8_error_t data_database_sql_builder_build_update_classifier_name_cmd ( data_dat
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_classifier_name, 0, DATA_CLASSIFIER_MAX_NAME_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_classifier_name ) > DATA_CLASSIFIER_MAX_NAME_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_classifier_name );
+        if ( new_length <= DATA_CLASSIFIER_MAX_NAME_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_classifier_name );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_classifier_name, DATA_CLASSIFIER_MAX_NAME_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -715,12 +761,21 @@ u8_error_t data_database_sql_builder_build_update_classifier_description_cmd ( d
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_classifier_description, 0, DATA_CLASSIFIER_MAX_DESCRIPTION_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_classifier_description ) > DATA_CLASSIFIER_MAX_DESCRIPTION_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_classifier_description );
+        if ( new_length <= DATA_CLASSIFIER_MAX_DESCRIPTION_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_classifier_description );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_classifier_description, DATA_CLASSIFIER_MAX_DESCRIPTION_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1247,12 +1302,21 @@ u8_error_t data_database_sql_builder_build_update_feature_key_cmd ( data_databas
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_feature_key, 0, DATA_FEATURE_MAX_KEY_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_feature_key ) > DATA_FEATURE_MAX_KEY_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_feature_key );
+        if ( new_length <= DATA_FEATURE_MAX_KEY_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_feature_key );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_feature_key, DATA_FEATURE_MAX_KEY_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1286,12 +1350,21 @@ u8_error_t data_database_sql_builder_build_update_feature_value_cmd ( data_datab
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_feature_value, 0, DATA_FEATURE_MAX_VALUE_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_feature_value ) > DATA_FEATURE_MAX_VALUE_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_feature_value );
+        if ( new_length <= DATA_FEATURE_MAX_VALUE_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_feature_value );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_feature_value, DATA_FEATURE_MAX_VALUE_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1325,12 +1398,21 @@ u8_error_t data_database_sql_builder_build_update_feature_description_cmd ( data
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_feature_description, 0, DATA_FEATURE_MAX_DESCRIPTION_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_feature_description ) > DATA_FEATURE_MAX_DESCRIPTION_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_feature_description );
+        if ( new_length <= DATA_FEATURE_MAX_DESCRIPTION_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_feature_description );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_feature_description, DATA_FEATURE_MAX_DESCRIPTION_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1618,12 +1700,21 @@ u8_error_t data_database_sql_builder_build_update_relationship_stereotype_cmd (
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_relationship_stereotype, 0, DATA_RELATIONSHIP_MAX_STEREOTYPE_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_relationship_stereotype ) > DATA_RELATIONSHIP_MAX_STEREOTYPE_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_relationship_stereotype );
+        if ( new_length <= DATA_RELATIONSHIP_MAX_STEREOTYPE_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_relationship_stereotype );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_relationship_stereotype, DATA_RELATIONSHIP_MAX_STEREOTYPE_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1659,12 +1750,21 @@ u8_error_t data_database_sql_builder_build_update_relationship_name_cmd ( data_d
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_relationship_name, 0, DATA_RELATIONSHIP_MAX_NAME_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_relationship_name ) > DATA_RELATIONSHIP_MAX_NAME_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_relationship_name );
+        if ( new_length <= DATA_RELATIONSHIP_MAX_NAME_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_relationship_name );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_relationship_name, DATA_RELATIONSHIP_MAX_NAME_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1698,12 +1798,21 @@ u8_error_t data_database_sql_builder_build_update_relationship_description_cmd (
     strerr |= utf8stringbuf_append_str( (*this_).sql_stringbuf, DATA_DATABASE_SQL_BUILDER_STRING_VALUE_START );
     {
         /* prepare temp buf */
-        utf8stringbuf_copy_region_from_str( (*this_).temp_stringbuf, new_relationship_description, 0, DATA_RELATIONSHIP_MAX_DESCRIPTION_LENGTH );
-        /* do not evaluate the result of above call, it may be UTF8ERROR_OUT_OF_RANGE but this is expected. */
-        if ( utf8string_get_length( new_relationship_description ) > DATA_RELATIONSHIP_MAX_DESCRIPTION_LENGTH )
+        /* copy the string but not more than the maximum allowed bytes: */
+        utf8stringview_t shortened_text;
+        const size_t new_length = utf8string_get_length( new_relationship_description );
+        if ( new_length <= DATA_RELATIONSHIP_MAX_DESCRIPTION_LENGTH )
+        {
+            utf8stringview_init_str( &shortened_text, new_relationship_description );
+        }
+        else
         {
             strerr |= UTF8ERROR_TRUNCATED;
+            utf8stringview_init( &shortened_text, new_relationship_description, DATA_RELATIONSHIP_MAX_DESCRIPTION_LENGTH );
+            /* ignore a possible UTF8ERROR_OUT_OF_RANGE result */
         }
+        utf8stringbuf_copy_view( (*this_).temp_stringbuf, &shortened_text );
+        utf8stringview_destroy( &shortened_text );
         strerr |= utf8stringbuf_replace_all( (*this_).temp_stringbuf, &DATA_DATABASE_SQL_BUILDER_SQL_ENCODE );
     }
     strerr |= utf8stringbuf_append_buf( (*this_).sql_stringbuf, (*this_).temp_stringbuf );
@@ -1752,7 +1861,7 @@ u8_error_t data_database_sql_builder_build_update_relationship_list_order_cmd (
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
