@@ -6,6 +6,8 @@
 /* public file for the doxygen documentation: */
 /*! \file
  *  \brief Data objects needed to display an element type: name and icon
+ *
+ *  This data object is a gobject to be able to store it in a GListModel like GListStore.
  */
 
 #include "data_table.h"
@@ -15,18 +17,37 @@
 #include "data_diagram_type.h"
 #include "data_type.h"
 #include <gdk/gdk.h>
+#include <glib-object.h>
 #include <stdint.h>
 
+G_BEGIN_DECLS
+
+/*
+ * Type declaration.
+ */
+#define GUI_TYPE_TYPE_RESOURCE gui_type_resource_get_type()
+G_DECLARE_FINAL_TYPE (GuiTypeResource, gui_type_resource, GUI, TYPE_RESOURCE, GObject)
+
 /*!
  *  \brief attributes of the type resource
+ *
+ *  The notation of the struct name is required by glib
  */
-struct gui_type_resource_struct {
-    data_type_t type;  /*!<  element type for which this type resource applies */
+struct _GuiTypeResource {
+    GObject parent_instance;  /*!<  glib parent object */
+    data_type_t type_id;  /*!<  element type for which this type resource applies */
     const char * name;  /*!<  display name */
-    GdkPixbuf * icon;  /*!<  icon to be displayed */
+    GdkTexture * icon;  /*!<  icon to be displayed */
 };
 
-typedef struct gui_type_resource_struct gui_type_resource_t;
+/*
+ * Method definitions.
+ */
+GuiTypeResource *gui_type_resource_new (void);
+
+G_END_DECLS
+
+typedef struct _GuiTypeResource gui_type_resource_t;
 
 /*!
  *  \brief initializes the gui_type_resource_t struct
@@ -39,7 +60,7 @@ typedef struct gui_type_resource_struct gui_type_resource_t;
 static inline void gui_type_resource_init_diagram ( gui_type_resource_t *this_,
                                                     data_diagram_type_t type,
                                                     const char * name,
-                                                    GdkPixbuf * icon
+                                                    GdkTexture * icon
                                                   );
 
 /*!
@@ -53,7 +74,7 @@ static inline void gui_type_resource_init_diagram ( gui_type_resource_t *this_,
 static inline void gui_type_resource_init_classifier ( gui_type_resource_t *this_,
                                                        data_classifier_type_t type,
                                                        const char * name,
-                                                       GdkPixbuf * icon
+                                                       GdkTexture * icon
                                                      );
 
 /*!
@@ -67,7 +88,7 @@ static inline void gui_type_resource_init_classifier ( gui_type_resource_t *this
 static inline void gui_type_resource_init_feature ( gui_type_resource_t *this_,
                                                     data_feature_type_t type,
                                                     const char * name,
-                                                    GdkPixbuf * icon
+                                                    GdkTexture * icon
                                                   );
 
 /*!
@@ -81,9 +102,19 @@ static inline void gui_type_resource_init_feature ( gui_type_resource_t *this_,
 static inline void gui_type_resource_init_relationship ( gui_type_resource_t *this_,
                                                          data_relationship_type_t type,
                                                          const char * name,
-                                                         GdkPixbuf * icon
+                                                         GdkTexture * icon
                                                        );
 
+/*!
+ *  \brief initializes the gui_type_resource_t struct with a copy
+ *
+ *  parent_instance is not modified.
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param original pointer to object attributes to copy
+ */
+static inline void gui_type_resource_replace ( gui_type_resource_t *this_, const gui_type_resource_t *original );
+
 /*!
  *  \brief destroys the gui_type_resource_t struct
  *
@@ -91,13 +122,24 @@ static inline void gui_type_resource_init_relationship ( gui_type_resource_t *th
  */
 static inline void gui_type_resource_destroy ( gui_type_resource_t *this_ );
 
+/*!
+ *  \brief checks if two gui_type_resource_t are equal
+ *
+ *  This function can be used as type GEqualFunc
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param that pointer to other object attributes
+ *  \return TRUE if equal
+ */
+gboolean gui_type_resource_equal( const gui_type_resource_t *this_, const gui_type_resource_t *that );
+
 /*!
  *  \brief gets the type
  *
  *  \param this_ pointer to own object attributes
- *  \return type of this gui_type_resource_t
+ *  \return type_id of this gui_type_resource_t
  */
-static inline const data_type_t * gui_type_resource_get_type ( const gui_type_resource_t *this_ );
+static inline const data_type_t * gui_type_resource_get_type_id ( const gui_type_resource_t *this_ );
 
 /*!
  *  \brief gets the name
@@ -110,12 +152,12 @@ static inline const char * gui_type_resource_get_name ( const gui_type_resource_
 /*!
  *  \brief gets the icon
  *
- *  GdkPixbuf cannot be const because most gtk functions require mutable GdkPixbuf as parameter.
+ *  GdkTexture cannot be const because most gtk functions require mutable GdkTexture as parameter.
  *
  *  \param this_ pointer to own object attributes
  *  \return icon of this gui_type_resource_t
  */
-static inline GdkPixbuf * gui_type_resource_get_icon ( const gui_type_resource_t *this_ );
+static inline GdkTexture * gui_type_resource_get_icon ( const gui_type_resource_t *this_ );
 
 #include "gui_type_resource.inl"
 
@@ -123,7 +165,7 @@ static inline GdkPixbuf * gui_type_resource_get_icon ( const gui_type_resource_t
 
 
 /*
-Copyright 2020-2023 Andreas Warnke
+Copyright 2020-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
