@@ -15,11 +15,19 @@
 #include <gtk/gtk.h>
 #include <stdbool.h>
 
+#if ( GTK_MAJOR_VERSION < 4 )
+#define gtk_widget_set_visible(w,v) ((v)?gtk_widget_show(w):gtk_widget_hide(w))
+#endif
+
 void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
                                   GtkLabel *id_label,
                                   GtkEntry *name_entry,
                                   GtkEntry *stereotype_entry,
+#if ( GTK_MAJOR_VERSION >= 4 )
+                                  GtkDropDown *type_dropdown,
+#else
                                   GtkComboBox *type_combo_box,
+#endif
                                   GtkWidget *type_diag_grid,
                                   GtkWidget *type_clas_grid,
                                   GtkWidget *type_feat_grid,
@@ -36,7 +44,11 @@ void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
     assert( NULL != id_label );
     assert( NULL != name_entry );
     assert( NULL != stereotype_entry );
+#if ( GTK_MAJOR_VERSION >= 4 )
+    assert( NULL != type_dropdown );
+#else
     assert( NULL != type_combo_box );
+#endif
     assert( NULL != type_diag_grid );
     assert( NULL != type_clas_grid );
     assert( NULL != type_feat_grid );
@@ -52,7 +64,11 @@ void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
     (*this_).id_label = id_label;
     (*this_).name_entry = name_entry;
     (*this_).stereotype_entry = stereotype_entry;
+#if ( GTK_MAJOR_VERSION >= 4 )
+    (*this_).type_dropdown = type_dropdown;
+#else
     (*this_).type_combo_box = type_combo_box;
+#endif
     (*this_).type_diag_grid = type_diag_grid;
     (*this_).type_clas_grid = type_clas_grid;
     (*this_).type_feat_grid = type_feat_grid;
@@ -73,7 +89,13 @@ void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
     data_relationship_init_empty( &((*this_).private_relationship_cache) );
     data_id_init_void( &((*this_).selected_object_id) );
 
+#if ( GTK_MAJOR_VERSION >= 4 )
+    gui_type_resource_list_init( &((*this_).type_lists), resources );
+    (*this_).temp_search_me = GUI_TYPE_RESOURCE( g_object_new( gui_type_resource_get_type(), NULL ) );
+    (*this_).previous_selected_object_id = DATA_ID_VOID;
+#else
     gui_attributes_editor_types_init( &((*this_).type_lists), resources );
+#endif
 
     /* update widgets */
     gui_attributes_editor_update_widgets( this_ );
@@ -93,7 +115,12 @@ void gui_attributes_editor_destroy ( gui_attributes_editor_t *this_ )
     data_id_destroy( &((*this_).second_latest_id) );
     data_id_destroy( &((*this_).latest_created_id) );
 
+#if ( GTK_MAJOR_VERSION >= 4 )
+    g_object_unref( (*this_).temp_search_me );
+    gui_type_resource_list_destroy( &((*this_).type_lists) );
+#else
     gui_attributes_editor_types_destroy( &((*this_).type_lists) );
+#endif
 
     (*this_).db_reader = NULL;
     (*this_).controller = NULL;
@@ -102,7 +129,11 @@ void gui_attributes_editor_destroy ( gui_attributes_editor_t *this_ )
     (*this_).id_label = NULL;
     (*this_).name_entry = NULL;
     (*this_).stereotype_entry = NULL;
+#if ( GTK_MAJOR_VERSION >= 4 )
+    (*this_).type_dropdown = NULL;
+#else
     (*this_).type_combo_box = NULL;
+#endif
     (*this_).type_diag_grid = NULL;
     (*this_).type_clas_grid = NULL;
     (*this_).type_feat_grid = NULL;
@@ -258,6 +289,20 @@ void gui_attributes_editor_trace ( const gui_attributes_editor_t *this_ )
     /* type: */
     if ( U8_TRACE_ACTIVE )
     {
+#if ( GTK_MAJOR_VERSION >= 4 )
+        int obj_type;
+        GObject *selected = gtk_drop_down_get_selected_item ( (*this_).type_dropdown );
+        if ( selected == NULL )
+        {
+            obj_type = -1;
+        }
+        else
+        {
+            const data_type_t *obj_full_type = gui_type_resource_get_type_id( ((GuiTypeResource*)selected) );
+            obj_type = data_type_get_type_as_int( obj_full_type );
+        }
+        U8_TRACE_INFO_INT( "- visible type id:", obj_type );
+#else
         GtkComboBox *type_widget;
         int obj_type;
         int index;
@@ -265,6 +310,7 @@ void gui_attributes_editor_trace ( const gui_attributes_editor_t *this_ )
         index = gtk_combo_box_get_active ( type_widget );
         obj_type = gtk_helper_tree_model_get_id( gtk_combo_box_get_model( type_widget ), 0, index );
         U8_TRACE_INFO_INT( "- visible type id:", obj_type );
+#endif
     }
 
     /* description: */
@@ -380,12 +426,46 @@ void gui_attributes_editor_stereotype_enter_callback ( GtkEntry *widget, gpointe
     U8_TRACE_END();
 }
 
+#if ( GTK_MAJOR_VERSION >= 4 )
+void gui_attributes_editor_type_changed_callback ( GObject* self, GParamSpec* pspec, gpointer user_data )
+{
+    U8_TRACE_BEGIN();
+    gui_attributes_editor_t *this_;
+    this_ = (gui_attributes_editor_t*) user_data;
+    assert ( NULL != this_ );
+    assert ( GTK_DROP_DOWN( self ) == (*this_).type_dropdown );
+
+    /* if the selected object has changed, this callback is triggered by that change, */
+    /* not by the user selecting another type */
+    bool user_requested = data_id_equals( &((*this_).previous_selected_object_id), &((*this_).selected_object_id) );
+    (*this_).previous_selected_object_id = (*this_).selected_object_id;
+
+    /* get type id from widget */
+    GObject *selected = gtk_drop_down_get_selected_item ( (*this_).type_dropdown );
+    if (( selected != NULL )&& user_requested )
+    {
+        const data_type_t *const obj_full_type
+            = gui_type_resource_get_type_id( ((GuiTypeResource*)selected) );
+        const int obj_type = data_type_get_type_as_int( obj_full_type );
+        U8_TRACE_INFO_INT( "selected type_id:", obj_type );
+
+        /* commit possibly changed texts before causing update events */
+        gui_attributes_editor_commit_changes( this_ );
+
+        gui_attributes_editor_private_type_commit_changes( this_, obj_type );
+    }
+
+    U8_TRACE_TIMESTAMP();
+    U8_TRACE_END();
+}
+#else
 void gui_attributes_editor_type_changed_callback ( GtkComboBox *widget, gpointer user_data )
 {
     U8_TRACE_BEGIN();
     gui_attributes_editor_t *this_;
     this_ = (gui_attributes_editor_t*) user_data;
     assert ( NULL != this_ );
+
     assert ( GTK_COMBO_BOX( widget ) == GTK_COMBO_BOX( (*this_).type_combo_box ) );
 
     /* get type id from widget */
@@ -394,7 +474,7 @@ void gui_attributes_editor_type_changed_callback ( GtkComboBox *widget, gpointer
     int index;
     type_widget = GTK_COMBO_BOX( (*this_).type_combo_box );
     index = gtk_combo_box_get_active ( type_widget );
-    U8_TRACE_INFO_INT( "selected:", index );
+    U8_TRACE_INFO_INT( "selected index:", index );
     obj_type = gtk_helper_tree_model_get_id( gtk_combo_box_get_model( type_widget ), 0, index );
 
     /* commit possibly changed texts before causing update events */
@@ -405,6 +485,7 @@ void gui_attributes_editor_type_changed_callback ( GtkComboBox *widget, gpointer
     U8_TRACE_TIMESTAMP();
     U8_TRACE_END();
 }
+#endif
 
 void gui_attributes_editor_type_of_diagram_btn_callback( GtkWidget* button, gpointer data )
 {
@@ -1440,13 +1521,13 @@ void gui_attributes_editor_private_name_update_view ( gui_attributes_editor_t *t
         case DATA_TABLE_VOID:
         {
             /* prevent that a user accitentially enters text to a non-existing object */
-            gtk_widget_hide ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), FALSE );
         }
         break;
 
         case DATA_TABLE_CLASSIFIER:
         {
-            gtk_widget_show ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), TRUE );
 
             const char *const text
                 = data_classifier_get_name_const( &((*this_).private_classifier_cache) );
@@ -1461,7 +1542,7 @@ void gui_attributes_editor_private_name_update_view ( gui_attributes_editor_t *t
 
         case DATA_TABLE_FEATURE:
         {
-            gtk_widget_show ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), TRUE );
 
             const char *const text
                 = data_feature_get_key_const( &((*this_).private_feature_cache) );
@@ -1476,7 +1557,7 @@ void gui_attributes_editor_private_name_update_view ( gui_attributes_editor_t *t
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            gtk_widget_show ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), TRUE );
 
             const char *const text
                 = data_relationship_get_name_const( &((*this_).private_relationship_cache) );
@@ -1491,13 +1572,13 @@ void gui_attributes_editor_private_name_update_view ( gui_attributes_editor_t *t
 
         case DATA_TABLE_DIAGRAMELEMENT:
         {
-            gtk_widget_hide ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), FALSE );
         }
         break;
 
         case DATA_TABLE_DIAGRAM:
         {
-            gtk_widget_show ( GTK_WIDGET ( name_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( name_widget ), TRUE );
 
             const char *const text
                 = data_diagram_get_name_const( &((*this_).private_diagram_cache) );
@@ -1537,7 +1618,7 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
         case DATA_TABLE_VOID:
         {
             /* prevent that a user accitentially enters text to a non-existing object */
-            gtk_widget_hide ( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), FALSE );
             /*gtk_entry_set_text( GTK_ENTRY ( stereotype_widget ), "    -- n/a --" );*/
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), false );
         }
@@ -1545,7 +1626,7 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
 
         case DATA_TABLE_CLASSIFIER:
         {
-            gtk_widget_show( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), TRUE );
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), true );
 
             const char *const text
@@ -1561,7 +1642,7 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
 
         case DATA_TABLE_FEATURE:
         {
-            gtk_widget_show( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), TRUE );
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), true );
 
             const char *const text
@@ -1577,7 +1658,7 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            gtk_widget_show( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), TRUE );
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), true );
 
             const char *const text
@@ -1593,14 +1674,14 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
 
         case DATA_TABLE_DIAGRAMELEMENT:
         {
-            gtk_widget_hide( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), FALSE );
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), false );
         }
         break;
 
         case DATA_TABLE_DIAGRAM:
         {
-            gtk_widget_show( GTK_WIDGET ( stereotype_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( stereotype_widget ), TRUE );
             gtk_editable_set_editable ( GTK_EDITABLE ( stereotype_widget ), true );
 
             const char *const text
@@ -1627,29 +1708,53 @@ void gui_attributes_editor_private_stereotype_update_view ( gui_attributes_edito
 void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *this_ )
 {
     U8_TRACE_BEGIN();
+#if ( GTK_MAJOR_VERSION >= 4 )
+    GtkDropDown *type_widget = (*this_).type_dropdown;
+#else
     GtkComboBox *type_widget;
     type_widget = GTK_COMBO_BOX( (*this_).type_combo_box );
+#endif
 
     switch ( data_id_get_table( &((*this_).selected_object_id ) ) )
     {
         case DATA_TABLE_VOID:
         {
-            gtk_widget_hide ( GTK_WIDGET ( type_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( type_widget ), FALSE );
+#if ( GTK_MAJOR_VERSION >= 4 )
+            GListStore *const undef_type_list = gui_type_resource_list_get_undef( &((*this_).type_lists) );
+            gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( undef_type_list ) );
+#else
             const GtkListStore * const undef_type_list = gui_attributes_editor_types_get_undef( &((*this_).type_lists) );
             gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( undef_type_list ) );
             /* prevent that a user accidentally enters a type for a non-existing object */
+#endif
 
             /* hide icon grid: */
-            gtk_widget_hide( (*this_).type_diag_grid );
-            gtk_widget_hide( (*this_).type_clas_grid );
-            gtk_widget_hide( (*this_).type_feat_grid );
-            gtk_widget_hide( (*this_).type_rel_grid );
+            gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
         }
         break;
 
         case DATA_TABLE_CLASSIFIER:
         {
             const data_classifier_type_t class_type = data_classifier_get_main_type( &((*this_).private_classifier_cache) );
+#if ( GTK_MAJOR_VERSION >= 4 )
+            GListStore *const classifier_type_list = gui_type_resource_list_get_classifiers( &((*this_).type_lists) );
+            gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( classifier_type_list ) );
+            guint selected_pos;
+            gui_type_resource_init_classifier( (*this_).temp_search_me, class_type, "", NULL );  /* type, name, icon */
+            const gboolean found = g_list_store_find_with_equal_func( classifier_type_list,
+                                                                      (*this_).temp_search_me,
+                                                                      (GEqualFunc)&gui_type_resource_equal,
+                                                                      &selected_pos
+                                                                    );
+            if ( found )
+            {
+                gtk_drop_down_set_selected( (*this_).type_dropdown, selected_pos );
+            }
+#else
             const GtkListStore * const classifier_type_list = gui_attributes_editor_types_get_classifiers( &((*this_).type_lists) );
             const int index = gtk_helper_tree_model_get_index( GTK_TREE_MODEL( classifier_type_list ), 0, class_type );
             gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( classifier_type_list ) );
@@ -1657,13 +1762,14 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
                 /* this set_active call is critical because it causes a callback to gui_attributes_editor_type_changed_callback */
                 gtk_combo_box_set_active ( GTK_COMBO_BOX( type_widget ), index );
             }
-            gtk_widget_show ( GTK_WIDGET ( type_widget ) );
+#endif
+            gtk_widget_set_visible( GTK_WIDGET ( type_widget ), TRUE );
 
             /* show classifier icon grid: */
-            gtk_widget_hide( (*this_).type_diag_grid );
-            gtk_widget_show( (*this_).type_clas_grid );
-            gtk_widget_hide( (*this_).type_feat_grid );
-            gtk_widget_hide( (*this_).type_rel_grid );
+            gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_clas_grid, TRUE );
+            gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
         }
         break;
 
@@ -1672,6 +1778,21 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
             const data_feature_type_t feature_type = data_feature_get_main_type( &((*this_).private_feature_cache) );
             if ( DATA_FEATURE_TYPE_LIFELINE == feature_type )
             {
+#if ( GTK_MAJOR_VERSION >= 4 )
+                GListStore *const lifeline_type_list = gui_type_resource_list_get_feature_lifeline( &((*this_).type_lists) );
+                gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( lifeline_type_list ) );
+                guint selected_pos;
+                gui_type_resource_init_feature( (*this_).temp_search_me, feature_type, "", NULL ); /* type, name, icon */
+                const gboolean found = g_list_store_find_with_equal_func( lifeline_type_list,
+                                                                          (*this_).temp_search_me,
+                                                                          (GEqualFunc)&gui_type_resource_equal,
+                                                                          &selected_pos
+                                                                        );
+                if ( found )
+                {
+                    gtk_drop_down_set_selected( (*this_).type_dropdown, selected_pos );
+                }
+#else
                 const GtkListStore * const lifeline_type_list = gui_attributes_editor_types_get_feature_lifeline( &((*this_).type_lists) );
                 const int index2 = gtk_helper_tree_model_get_index( GTK_TREE_MODEL( lifeline_type_list ), 0, feature_type );
                 gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( lifeline_type_list ) );
@@ -1679,16 +1800,32 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
                     /* this set_active call is critical because it causes a callback to gui_attributes_editor_type_changed_callback */
                     gtk_combo_box_set_active ( GTK_COMBO_BOX( type_widget ), index2 );
                 }
-                gtk_widget_show ( GTK_WIDGET ( type_widget ) );
+#endif
+                gtk_widget_set_visible( GTK_WIDGET ( type_widget ), TRUE );
 
                 /* hide  icon grid: */
-                gtk_widget_hide( (*this_).type_diag_grid );
-                gtk_widget_hide( (*this_).type_clas_grid );
-                gtk_widget_hide( (*this_).type_feat_grid );
-                gtk_widget_hide( (*this_).type_rel_grid );
+                gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+                gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+                gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+                gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
             }
             else
             {
+#if ( GTK_MAJOR_VERSION >= 4 )
+                GListStore *const feature_type_list = gui_type_resource_list_get_features( &((*this_).type_lists) );
+                gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( feature_type_list ) );
+                guint selected_pos;
+                gui_type_resource_init_feature( (*this_).temp_search_me, feature_type, "", NULL ); /* type, name, icon */
+                const gboolean found = g_list_store_find_with_equal_func( feature_type_list,
+                                                                          (*this_).temp_search_me,
+                                                                          (GEqualFunc)&gui_type_resource_equal,
+                                                                          &selected_pos
+                                                                        );
+                if ( found )
+                {
+                    gtk_drop_down_set_selected( (*this_).type_dropdown, selected_pos );
+                }
+#else
                 const GtkListStore * const feature_type_list = gui_attributes_editor_types_get_features( &((*this_).type_lists) );
                 const int index = gtk_helper_tree_model_get_index( GTK_TREE_MODEL( feature_type_list ), 0, feature_type );
                 gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( feature_type_list ) );
@@ -1696,54 +1833,92 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
                     /* this set_active call is critical because it causes a callback to gui_attributes_editor_type_changed_callback */
                     gtk_combo_box_set_active ( GTK_COMBO_BOX( type_widget ), index );
                 }
-                gtk_widget_show ( GTK_WIDGET ( type_widget ) );
+#endif
+                gtk_widget_set_visible( GTK_WIDGET ( type_widget ), TRUE );
 
                 /* show feature icon grid: */
-                gtk_widget_hide( (*this_).type_diag_grid );
-                gtk_widget_hide( (*this_).type_clas_grid );
-                gtk_widget_show( (*this_).type_feat_grid );
-                gtk_widget_hide( (*this_).type_rel_grid );
+                gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+                gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+                gtk_widget_set_visible( (*this_).type_feat_grid, TRUE );
+                gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
             }
         }
         break;
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            const data_relationship_type_t relationship_type = data_relationship_get_main_type( &((*this_).private_relationship_cache) );
+            const data_relationship_type_t relationship_type
+                = data_relationship_get_main_type( &((*this_).private_relationship_cache) );
+#if ( GTK_MAJOR_VERSION >= 4 )
+            GListStore *const relationship_type_list = gui_type_resource_list_get_relationships( &((*this_).type_lists) );
+            gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( relationship_type_list ) );
+            guint selected_pos;
+            gui_type_resource_init_relationship( (*this_).temp_search_me, relationship_type, "", NULL ); /* type, name, icon */
+            const gboolean found = g_list_store_find_with_equal_func( relationship_type_list,
+                                                                      (*this_).temp_search_me,
+                                                                      (GEqualFunc)&gui_type_resource_equal,
+                                                                      &selected_pos
+                                                                    );
+            if ( found )
+            {
+                gtk_drop_down_set_selected( (*this_).type_dropdown, selected_pos );
+            }
+#else
             const GtkListStore * const relationship_type_list = gui_attributes_editor_types_get_relationships( &((*this_).type_lists) );
             const int index = gtk_helper_tree_model_get_index( GTK_TREE_MODEL( relationship_type_list ), 0, relationship_type );
             gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( relationship_type_list ) );
             if ( index != -1 ) {
                 /* this set_active call is critical because it causes a callback to gui_attributes_editor_type_changed_callback */
-                gtk_combo_box_set_active ( GTK_COMBO_BOX( type_widget ), index );
+                gtk_combo_box_set_active( GTK_COMBO_BOX( type_widget ), index );
             }
-            gtk_widget_show ( GTK_WIDGET ( type_widget ) );
+#endif
+            gtk_widget_set_visible( GTK_WIDGET ( type_widget ), TRUE );
 
             /* show relationship icon grid: */
-            gtk_widget_hide( (*this_).type_diag_grid );
-            gtk_widget_hide( (*this_).type_clas_grid );
-            gtk_widget_hide( (*this_).type_feat_grid );
-            gtk_widget_show( (*this_).type_rel_grid );
+            gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_rel_grid, TRUE );
         }
         break;
 
         case DATA_TABLE_DIAGRAMELEMENT:
         {
-            gtk_widget_hide ( GTK_WIDGET ( type_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( type_widget ), FALSE );
+#if ( GTK_MAJOR_VERSION >= 4 )
+            GListStore *const undef_type_list = gui_type_resource_list_get_undef( &((*this_).type_lists) );
+            gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( undef_type_list ) );
+#else
             const GtkListStore * const undef_type_list = gui_attributes_editor_types_get_undef( &((*this_).type_lists) );
             gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( undef_type_list ) );
+#endif
 
             /* hide icon grid: */
-            gtk_widget_hide( (*this_).type_diag_grid );
-            gtk_widget_hide( (*this_).type_clas_grid );
-            gtk_widget_hide( (*this_).type_feat_grid );
-            gtk_widget_hide( (*this_).type_rel_grid );
+            gtk_widget_set_visible( (*this_).type_diag_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
         }
         break;
 
         case DATA_TABLE_DIAGRAM:
         {
             const data_diagram_type_t diag_type = data_diagram_get_diagram_type( &((*this_).private_diagram_cache) );
+#if ( GTK_MAJOR_VERSION >= 4 )
+            GListStore *const diagram_type_list = gui_type_resource_list_get_diagrams( &((*this_).type_lists) );
+            gtk_drop_down_set_model( (*this_).type_dropdown, G_LIST_MODEL( diagram_type_list ) );
+            guint selected_pos;
+            gui_type_resource_init_diagram( (*this_).temp_search_me, diag_type, "", NULL ); /* type, name, icon */
+            const gboolean found = g_list_store_find_with_equal_func( diagram_type_list,
+                                                                      (*this_).temp_search_me,
+                                                                      (GEqualFunc)&gui_type_resource_equal,
+                                                                      &selected_pos
+                                                                    );
+            if ( found )
+            {
+                gtk_drop_down_set_selected( (*this_).type_dropdown, selected_pos );
+            }
+#else
             const GtkListStore * const diagram_type_list = gui_attributes_editor_types_get_diagrams( &((*this_).type_lists) );
             const int index = gtk_helper_tree_model_get_index( GTK_TREE_MODEL( diagram_type_list ), 0, diag_type );
             gtk_combo_box_set_model( GTK_COMBO_BOX( type_widget ), GTK_TREE_MODEL( diagram_type_list ) );
@@ -1751,13 +1926,14 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
                 /* this set_active call is critical because it causes a callback to gui_attributes_editor_type_changed_callback */
                 gtk_combo_box_set_active ( GTK_COMBO_BOX( type_widget ), index );
             }
-            gtk_widget_show ( GTK_WIDGET ( type_widget ) );
+#endif
+            gtk_widget_set_visible( GTK_WIDGET ( type_widget ), TRUE );
 
             /* show diagram icon grid: */
-            gtk_widget_show( (*this_).type_diag_grid );
-            gtk_widget_hide( (*this_).type_clas_grid );
-            gtk_widget_hide( (*this_).type_feat_grid );
-            gtk_widget_hide( (*this_).type_rel_grid );
+            gtk_widget_set_visible( (*this_).type_diag_grid, TRUE );
+            gtk_widget_set_visible( (*this_).type_clas_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_feat_grid, FALSE );
+            gtk_widget_set_visible( (*this_).type_rel_grid, FALSE );
         }
         break;
 
@@ -1785,13 +1961,13 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
         case DATA_TABLE_VOID:
         {
             /* prevent that a user accitentially enters text to a non-existing object */
-            gtk_widget_hide ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), FALSE );
         }
         break;
 
         case DATA_TABLE_CLASSIFIER:
         {
-            gtk_widget_show ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), TRUE );
 
             const char* text;
             text = data_classifier_get_description_const( &((*this_).private_classifier_cache) );
@@ -1801,7 +1977,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
         case DATA_TABLE_FEATURE:
         {
-            gtk_widget_show ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), TRUE );
 
             const char* text;
             text = data_feature_get_description_const( &((*this_).private_feature_cache) );
@@ -1811,7 +1987,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            gtk_widget_show ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), TRUE );
 
             const char* text;
             text = data_relationship_get_description_const( &((*this_).private_relationship_cache) );
@@ -1821,13 +1997,13 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
         case DATA_TABLE_DIAGRAMELEMENT:
         {
-            gtk_widget_hide ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), FALSE );
         }
         break;
 
         case DATA_TABLE_DIAGRAM:
         {
-            gtk_widget_show ( GTK_WIDGET ( description_widget ) );
+            gtk_widget_set_visible( GTK_WIDGET ( description_widget ), TRUE );
 
             const char* text;
             text = data_diagram_get_description_const( &((*this_).private_diagram_cache) );
@@ -1847,7 +2023,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
