@@ -2,6 +2,7 @@
 
 #include "gui_main_window.h"
 #include "gui_clipboard.h"
+#include "gui_type_resource.h"
 #include "u8/u8_trace.h"
 #include "data_diagram_type.h"
 #include "data_classifier_type.h"
@@ -19,6 +20,10 @@
 #include <stdio.h>
 #include <stdbool.h>
 
+#if ( GTK_MAJOR_VERSION < 4 )
+#define gtk_widget_set_visible(w,v) ((v)?gtk_widget_show(w):gtk_widget_hide(w))
+#endif
+
 void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
                            io_data_file_t *data_file,
@@ -137,7 +142,11 @@ void gui_main_window_init( gui_main_window_t *this_,
                                 GTK_LABEL( (*this_).id_label ),
                                 GTK_ENTRY( (*this_).name_entry ),
                                 GTK_ENTRY( (*this_).stereotype_entry ),
+#if ( GTK_MAJOR_VERSION >= 4 )
+                                (*this_).type_dropdown,
+#else
                                 GTK_COMBO_BOX( (*this_).type_combo_box ),
+#endif
                                 GTK_WIDGET( (*this_).type_diag_grid ),
                                 GTK_WIDGET( (*this_).type_clas_grid ),
                                 GTK_WIDGET( (*this_).type_feat_grid ),
@@ -312,8 +321,12 @@ void gui_main_window_init( gui_main_window_t *this_,
                     );
 #endif
     g_signal_connect( G_OBJECT((*this_).stereotype_entry), "activate", G_CALLBACK(gui_attributes_editor_stereotype_enter_callback), &((*this_).attributes_editor) );
+#if ( GTK_MAJOR_VERSION >= 4 )
+    g_signal_connect_after( G_OBJECT((*this_).type_dropdown), "notify::selected", G_CALLBACK(gui_attributes_editor_type_changed_callback), &((*this_).attributes_editor));
+#else
     g_signal_connect( G_OBJECT((*this_).type_combo_box), "changed", G_CALLBACK(gui_attributes_editor_type_changed_callback), &((*this_).attributes_editor) );
-    for( int_fast32_t diag_idx = 0; diag_idx < GUI_RESOURCE_SELECTOR_DIAGRAMS; diag_idx ++ )
+#endif
+    for( int_fast32_t diag_idx = 0; diag_idx < GUI_TYPE_RESOURCE_LIST_DIAGRAMS; diag_idx ++ )
     {
         g_signal_connect( G_OBJECT((*this_).type_diag_btn[ diag_idx ]),
                           "clicked",
@@ -321,7 +334,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                           &((*this_).type_diag_data[diag_idx])
                         );
     }
-    for( int_fast32_t clas_idx = 0; clas_idx < GUI_RESOURCE_SELECTOR_CLASSIFIERS; clas_idx ++ )
+    for( int_fast32_t clas_idx = 0; clas_idx < GUI_TYPE_RESOURCE_LIST_CLASSIFIERS; clas_idx ++ )
     {
         g_signal_connect( G_OBJECT((*this_).type_clas_btn[ clas_idx ]),
                           "clicked",
@@ -329,7 +342,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                           &((*this_).type_clas_data[clas_idx])
                         );
     }
-    for( int_fast32_t feat_idx = 0; feat_idx < GUI_RESOURCE_SELECTOR_INV_FEATURES; feat_idx ++ )
+    for( int_fast32_t feat_idx = 0; feat_idx < GUI_TYPE_RESOURCE_LIST_INV_FEATURES; feat_idx ++ )
     {
         g_signal_connect( G_OBJECT((*this_).type_feat_btn[ feat_idx ]),
                           "clicked",
@@ -337,7 +350,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                           &((*this_).type_feat_data[feat_idx])
                         );
     }
-    for( int_fast32_t rel_idx = 0; rel_idx < GUI_RESOURCE_SELECTOR_RELATIONS; rel_idx ++ )
+    for( int_fast32_t rel_idx = 0; rel_idx < GUI_TYPE_RESOURCE_LIST_RELATIONS; rel_idx ++ )
     {
         g_signal_connect( G_OBJECT((*this_).type_rel_btn[ rel_idx ]),
                           "clicked",
@@ -365,7 +378,7 @@ void gui_main_window_init( gui_main_window_t *this_,
     U8_TRACE_INFO("GTK+ Widgets are registered as listeners at signal emitter.");
 
 #if ( GTK_MAJOR_VERSION >= 4 )
-    gtk_widget_show((*this_).window);
+    gtk_widget_set_visible( (*this_).window, TRUE );
     gtk_widget_set_sensitive( GTK_WIDGET((*this_).window), TRUE );  /* idea taken from gtk demo */
 
     GdkSurface *surface = gtk_native_get_surface( GTK_NATIVE((*this_).window) );
@@ -426,20 +439,20 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 {
     U8_TRACE_BEGIN();
 
-    (*this_).file_new_db_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_new_db( res ));
+    (*this_).file_new_db_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_file_new_db( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_new_db_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).file_new_db = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).file_new_db), (*this_).file_new_db_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_new_db), "New DB" );
 
-    (*this_).file_use_db_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_use_db( res ));
+    (*this_).file_use_db_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_file_use_db( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_use_db_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).file_use_db = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).file_use_db), (*this_).file_use_db_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_use_db), "Open DB" );
 
     (*this_).file_save_button = gtk_button_new();
-    (*this_).file_save_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_save( res ));
+    (*this_).file_save_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_file_save( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_save_icon), 32 /*=w*/ , 32 /*=h*/ );
     gtk_button_set_image( GTK_BUTTON((*this_).file_save_button), (*this_).file_save_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_save_button), "Save (Ctrl-S)" );
@@ -465,20 +478,20 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #endif
 
 #if 0
-    (*this_).file_save_as_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_save_as( res ));
+    (*this_).file_save_as_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_file_save_as( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_save_as_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).file_save_as = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).file_save_as), (*this_).file_save_as_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_save_as), "Save as" );
 #endif
 
-    (*this_).file_export_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_export( res ));
+    (*this_).file_export_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_file_export( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_export_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).file_export = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).file_export), (*this_).file_export_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_export), "Export" );
 
-    (*this_).tool_sect_1_icon = gtk_image_new_from_pixbuf ( gui_resources_get_tool_sect( res ) );
+    (*this_).tool_sect_1_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_tool_sect( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_sect_1_icon), 12 /*=w*/ , 32 /*=h*/ );
 #if ( GTK_MAJOR_VERSION >= 4 )
     gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_1_icon), 32 );
@@ -486,7 +499,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #endif
     gtk_widget_set_halign( (*this_).tool_sect_1_icon, GTK_ALIGN_START );
 
-     (*this_).tool_sect_2_icon = gtk_image_new_from_pixbuf ( gui_resources_get_tool_sect( res ) );
+     (*this_).tool_sect_2_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_tool_sect( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_sect_2_icon), 12 /*=w*/ , 32 /*=h*/ );
 #if ( GTK_MAJOR_VERSION >= 4 )
     gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_2_icon), 32 );
@@ -494,19 +507,19 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #endif
     gtk_widget_set_halign( (*this_).tool_sect_2_icon, GTK_ALIGN_START );
 
-    (*this_).view_new_window_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_new_window( res ));
+    (*this_).view_new_window_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_new_window( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).view_new_window_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).view_new_window = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).view_new_window), (*this_).view_new_window_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_new_window), "New Window" );
 
-    (*this_).view_navigate_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_navigate( res ));
+    (*this_).view_navigate_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_navigate( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).view_navigate_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).view_edit_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_edit( res ));
+    (*this_).view_edit_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_edit( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).view_edit_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).view_create_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_create( res ));
+    (*this_).view_create_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_create( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).view_create_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).view_search_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_search( res ));
+    (*this_).view_search_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_search( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).view_search_icon), 32 /*=w*/ , 32 /*=h*/ );
 #if ( GTK_MAJOR_VERSION >= 4 )
     (*this_).view_navigate = gtk_toggle_button_new();
@@ -546,7 +559,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_create), "Create" );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_search), "Search" );
 
-    (*this_).edit_undo_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_undo( res ));
+    (*this_).edit_undo_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_undo( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_undo_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_undo = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_undo), (*this_).edit_undo_icon );
@@ -573,7 +586,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 
 #endif
 
-    (*this_).edit_redo_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_redo( res ));
+    (*this_).edit_redo_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_redo( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_redo_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_redo = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_redo), (*this_).edit_redo_icon );
@@ -599,7 +612,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
                               );
 #endif
 
-    (*this_).edit_cut_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_cut( res ));
+    (*this_).edit_cut_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_cut( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_cut_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_cut = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_cut), (*this_).edit_cut_icon );
@@ -609,7 +622,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     moved there to not interfere with text input fields
     */
 
-    (*this_).edit_copy_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_copy( res ));
+    (*this_).edit_copy_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_copy( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_copy_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_copy = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_copy), (*this_).edit_copy_icon );
@@ -619,7 +632,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     moved there to not interfere with text input fields
     */
 
-    (*this_).edit_paste_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_paste( res ));
+    (*this_).edit_paste_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_paste( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_paste_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_paste = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_paste), (*this_).edit_paste_icon );
@@ -629,7 +642,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     moved there to not interfere with text input fields
     */
 
-    (*this_).edit_delete_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_delete( res ));
+    (*this_).edit_delete_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_delete( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_delete_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_delete = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_delete), (*this_).edit_delete_icon );
@@ -639,25 +652,25 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     moved there to not interfere with text input fields
     */
 
-    (*this_).edit_instantiate_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_instantiate( res ));
+    (*this_).edit_instantiate_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_instantiate( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_instantiate_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_instantiate = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_instantiate), (*this_).edit_instantiate_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).edit_instantiate), "Instantiate" );
 
-    (*this_).edit_highlight_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_highlight( res ));
+    (*this_).edit_highlight_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_highlight( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_highlight_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_highlight = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_highlight), (*this_).edit_highlight_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).edit_highlight), "Highlight" );
 
-    (*this_).edit_reset_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_reset( res ));
+    (*this_).edit_reset_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_edit_reset( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_reset_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).edit_reset = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).edit_reset), (*this_).edit_reset_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).edit_reset), "Reset Selection" );
 
-    (*this_).tool_about_icon = gtk_image_new_from_pixbuf( gui_resources_get_crystal_facet_uml( res ));
+    (*this_).tool_about_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_crystal_facet_uml( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_about_icon), 32 /*=w*/ , 32 /*=h*/ );
     (*this_).tool_about = GTK_BUTTON(gtk_button_new());
     gtk_button_set_image( GTK_BUTTON((*this_).tool_about), (*this_).tool_about_icon );
@@ -722,7 +735,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
 {
     U8_TRACE_BEGIN();
 
-    (*this_).attr_section_icon = gtk_image_new_from_pixbuf ( gui_resources_get_edit_attributes_sect( res ) );
+    (*this_).attr_section_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_edit_attributes_sect( res ) ) );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).attr_section_icon), 48 /*=w*/ , 12 /*=h*/ );
 #if ( GTK_MAJOR_VERSION >= 4 )
     gtk_image_set_pixel_size( GTK_IMAGE((*this_).attr_section_icon), 48 );
@@ -751,7 +764,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
 #endif
 
     (*this_).id_search_btn = gtk_button_new();
-    (*this_).id_search_btn_icon = gtk_image_new_from_pixbuf( gui_resources_get_search_search( res ));
+    (*this_).id_search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_search_search( res ) ) );
     gtk_button_set_image( GTK_BUTTON((*this_).id_search_btn), (*this_).id_search_btn_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).id_search_btn), "Find Occurrences" );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).id_search_btn_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -805,6 +818,47 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
                                     GTK_POLICY_AUTOMATIC
                                   );
 
+#if ( GTK_MAJOR_VERSION >= 4 )
+    GListStore *model = NULL;  /* the model is set later */
+    GtkExpression *expression = NULL;  /* not needed: there is no search entry that could find list elements */
+    (*this_).type_dropdown = GTK_DROP_DOWN( gtk_drop_down_new ( G_LIST_MODEL( model ), expression ) );
+    GtkBuilderScope *scope = gtk_builder_cscope_new();
+    static const char bytes[] =
+    "<interface>\n"
+    "<template class=\"GtkListItem\">\n"
+    "  <property name=\"child\">\n"
+    "    <object class=\"GtkPaned\">\n"
+    "      <property name=\"start-child\">\n"
+    "        <object class=\"GtkImage\">\n"
+    "          <binding name=\"paintable\">\n"
+    "            <lookup name=\"icon\" type=\"GuiTypeResource\">\n"
+    "              <lookup name=\"item\">GtkListItem</lookup>\n"
+    "            </lookup>\n"
+    "          </binding>\n"
+    "        </object>\n"
+    "      </property>\n"
+    "      <property name=\"end-child\">\n"
+    "        <object class=\"GtkLabel\">\n"
+    "          <property name=\"xalign\">0</property>\n"
+    "          <binding name=\"label\">\n"
+    "            <lookup name=\"name\" type=\"GuiTypeResource\">\n"
+    "              <lookup name=\"item\">GtkListItem</lookup>\n"
+    "            </lookup>\n"
+    "          </binding>\n"
+    "        </object>\n"
+    "      </property>\n"
+    "      <property name=\"position\">48</property>\n"
+    "    </object>\n"
+    "  </property>\n"
+    "</template>\n"
+    "</interface>\n";
+    GBytes *byteptr = g_bytes_new( &bytes, sizeof(bytes)-sizeof(char) );
+    GtkListItemFactory *factory = gtk_builder_list_item_factory_new_from_bytes( scope, byteptr );
+    gtk_drop_down_set_factory( (*this_).type_dropdown, factory );
+    g_object_unref( scope );
+    g_object_unref( factory );
+    g_bytes_unref( byteptr );
+#else
     (*this_).type_combo_box = gtk_combo_box_new();
     GtkCellRenderer *column1;
     column1 = gtk_cell_renderer_pixbuf_new();
@@ -814,25 +868,26 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
     column2 = gtk_cell_renderer_text_new();
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT((*this_).type_combo_box), column2, /*expand:*/ TRUE);
     gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT((*this_).type_combo_box), column2, "text", 1, NULL);
+#endif
 
-    static gui_resource_selector_t res_select;
-    gui_resource_selector_init( &res_select, res );
+    static gui_type_resource_list_t res_select;
+    gui_type_resource_list_init( &res_select, res );
     {
         (*this_).type_diag_grid = GTK_GRID( gtk_grid_new() );
         gtk_widget_set_halign( GTK_WIDGET( (*this_).type_diag_grid ), GTK_ALIGN_END );
         const gui_type_resource_t (*diag_data)[];
         unsigned int diag_data_length;
-        gui_resource_selector_get_all_diagram_types( &res_select, &diag_data, &diag_data_length );
-        assert( diag_data_length == GUI_RESOURCE_SELECTOR_DIAGRAMS );
-        for( int_fast32_t diag_idx = 0; diag_idx < GUI_RESOURCE_SELECTOR_DIAGRAMS; diag_idx ++ )
+        gui_type_resource_list_get_all_diagram_types( &res_select, &diag_data, &diag_data_length );
+        assert( diag_data_length == GUI_TYPE_RESOURCE_LIST_DIAGRAMS );
+        for( int_fast32_t diag_idx = 0; diag_idx < GUI_TYPE_RESOURCE_LIST_DIAGRAMS; diag_idx ++ )
         {
             const gui_type_resource_t *const type_data = &((*diag_data)[diag_idx]);
-            const data_diagram_type_t diag_type = data_type_get_diagram_type( gui_type_resource_get_type( type_data ) );
-            GdkPixbuf *const diag_icon = gui_type_resource_get_icon( type_data );
+            const data_diagram_type_t diag_type = data_type_get_diagram_type( gui_type_resource_get_type_id( type_data ) );
+            GdkTexture *const diag_icon = gui_type_resource_get_icon( type_data );
             const char *const diag_name = gui_type_resource_get_name( type_data );
 
             gui_attribute_type_of_diagram_init( &((*this_).type_diag_data[diag_idx]), diag_type, &((*this_).attributes_editor) );
-            (*this_).type_diag_img[ diag_idx ] = GTK_IMAGE( gtk_image_new_from_pixbuf( diag_icon ) );
+            (*this_).type_diag_img[ diag_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( diag_icon ) ) );
             gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_diag_img[ diag_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
             (*this_).type_diag_btn[ diag_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_diag_btn[ diag_idx ], GTK_WIDGET( (*this_).type_diag_img[ diag_idx ] ) );
@@ -844,23 +899,17 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_widget_set_halign( GTK_WIDGET( (*this_).type_clas_grid ), GTK_ALIGN_END );
         const gui_type_resource_t (*clas_data)[];
         unsigned int clas_data_length;
-        gui_resource_selector_get_all_classifier_types( &res_select, &clas_data, &clas_data_length );
-        assert( clas_data_length == GUI_RESOURCE_SELECTOR_CLASSIFIERS );
-        for( int_fast32_t clas_idx = 0; clas_idx < GUI_RESOURCE_SELECTOR_CLASSIFIERS; clas_idx ++ )
+        gui_type_resource_list_get_all_classifier_types( &res_select, &clas_data, &clas_data_length );
+        assert( clas_data_length == GUI_TYPE_RESOURCE_LIST_CLASSIFIERS );
+        for( int_fast32_t clas_idx = 0; clas_idx < GUI_TYPE_RESOURCE_LIST_CLASSIFIERS; clas_idx ++ )
         {
             const gui_type_resource_t *const type_data = &((*clas_data)[clas_idx]);
-            const data_classifier_type_t clas_type = data_type_get_classifier_type( gui_type_resource_get_type( type_data ) );
-            GdkPixbuf *const clas_icon = gui_type_resource_get_icon( type_data );
+            const data_classifier_type_t clas_type = data_type_get_classifier_type( gui_type_resource_get_type_id( type_data ) );
+            GdkTexture *const clas_icon = gui_type_resource_get_icon( type_data );
             const char *const clas_name = gui_type_resource_get_name( type_data );
 
             gui_attribute_type_of_classifier_init( &((*this_).type_clas_data[clas_idx]), clas_type, &((*this_).attributes_editor) );
-#if ( GTK_MAJOR_VERSION >= 4 )
-            GdkTexture* texture = gdk_texture_new_for_pixbuf( clas_icon );
-            (*this_).type_clas_img[ clas_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( texture ) ) );
-            g_object_unref( texture );  /* no further need of texture here */
-#else
-            (*this_).type_clas_img[ clas_idx ] = GTK_IMAGE( gtk_image_new_from_pixbuf( clas_icon ) );
-#endif
+            (*this_).type_clas_img[ clas_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( clas_icon ) ) );
             gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_clas_img[ clas_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
             (*this_).type_clas_btn[ clas_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_clas_btn[ clas_idx ], GTK_WIDGET( (*this_).type_clas_img[ clas_idx ] ) );
@@ -872,17 +921,17 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_widget_set_halign( GTK_WIDGET( (*this_).type_feat_grid ), GTK_ALIGN_END );
         const gui_type_resource_t (*feat_data)[];
         unsigned int feat_data_length;
-        gui_resource_selector_get_invariant_feature_types( &res_select, &feat_data, &feat_data_length );
-        assert( feat_data_length == GUI_RESOURCE_SELECTOR_INV_FEATURES );
-        for( int_fast32_t feat_idx = 0; feat_idx < GUI_RESOURCE_SELECTOR_INV_FEATURES; feat_idx ++ )  /* ignore the lifeline */
+        gui_type_resource_list_get_invariant_feature_types( &res_select, &feat_data, &feat_data_length );
+        assert( feat_data_length == GUI_TYPE_RESOURCE_LIST_INV_FEATURES );
+        for( int_fast32_t feat_idx = 0; feat_idx < GUI_TYPE_RESOURCE_LIST_INV_FEATURES; feat_idx ++ )  /* ignore the lifeline */
         {
             const gui_type_resource_t *const type_data = &((*feat_data)[feat_idx]);
-            const data_feature_type_t feat_type = data_type_get_feature_type( gui_type_resource_get_type( type_data ) );
-            GdkPixbuf *const feat_icon = gui_type_resource_get_icon( type_data );
+            const data_feature_type_t feat_type = data_type_get_feature_type( gui_type_resource_get_type_id( type_data ) );
+            GdkTexture *const feat_icon = gui_type_resource_get_icon( type_data );
             const char *const feat_name = gui_type_resource_get_name( type_data );
 
             gui_attribute_type_of_feature_init( &((*this_).type_feat_data[feat_idx]), feat_type, &((*this_).attributes_editor) );
-            (*this_).type_feat_img[ feat_idx ] = GTK_IMAGE( gtk_image_new_from_pixbuf( feat_icon ) );
+            (*this_).type_feat_img[ feat_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( feat_icon ) ) );
             gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_feat_img[ feat_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
             (*this_).type_feat_btn[ feat_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_feat_btn[ feat_idx ], GTK_WIDGET( (*this_).type_feat_img[ feat_idx ] ) );
@@ -894,17 +943,17 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_widget_set_halign( GTK_WIDGET( (*this_).type_rel_grid ), GTK_ALIGN_END );
         const gui_type_resource_t (*rel_data)[];
         unsigned int rel_data_length;
-        gui_resource_selector_get_all_relationship_types( &res_select, &rel_data, &rel_data_length );
-        assert( rel_data_length == GUI_RESOURCE_SELECTOR_RELATIONS );
-        for( int_fast32_t rel_idx = 0; rel_idx < GUI_RESOURCE_SELECTOR_RELATIONS; rel_idx ++ )
+        gui_type_resource_list_get_all_relationship_types( &res_select, &rel_data, &rel_data_length );
+        assert( rel_data_length == GUI_TYPE_RESOURCE_LIST_RELATIONS );
+        for( int_fast32_t rel_idx = 0; rel_idx < GUI_TYPE_RESOURCE_LIST_RELATIONS; rel_idx ++ )
         {
             const gui_type_resource_t *const type_data = &((*rel_data)[rel_idx]);
-            const data_relationship_type_t rel_type = data_type_get_relationship_type( gui_type_resource_get_type( type_data ) );
-            GdkPixbuf *const rel_icon = gui_type_resource_get_icon( type_data );
+            const data_relationship_type_t rel_type = data_type_get_relationship_type( gui_type_resource_get_type_id( type_data ) );
+            GdkTexture *const rel_icon = gui_type_resource_get_icon( type_data );
             const char *const rel_name = gui_type_resource_get_name( type_data );
 
             gui_attribute_type_of_relationship_init( &((*this_).type_rel_data[rel_idx]), rel_type, &((*this_).attributes_editor) );
-            (*this_).type_rel_img[ rel_idx ] = GTK_IMAGE( gtk_image_new_from_pixbuf( rel_icon ) );
+            (*this_).type_rel_img[ rel_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( rel_icon ) ) );
             gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_rel_img[ rel_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
             (*this_).type_rel_btn[ rel_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_rel_btn[ rel_idx ], GTK_WIDGET( (*this_).type_rel_img[ rel_idx ] ) );
@@ -912,7 +961,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
             gtk_grid_attach( (*this_).type_rel_grid, GTK_WIDGET( (*this_).type_rel_btn[ rel_idx ] ), rel_idx%7, rel_idx/7, 1, 1 );
         }
     }
-    gui_resource_selector_destroy( &res_select );
+    gui_type_resource_list_destroy( &res_select );
 
     /* insert widgets to box container */
     {
@@ -924,11 +973,11 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).stereotype_label) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).stereotype_entry) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_label) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_combo_box) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_diag_grid ) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_clas_grid ) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_feat_grid ) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_rel_grid ) );
+        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_dropdown) );
+        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_diag_grid) );
+        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_clas_grid) );
+        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_feat_grid) );
+        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).type_rel_grid) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).description_label) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).description_scroll_win) );
 #else
@@ -939,10 +988,10 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).stereotype_entry) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_label) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_combo_box) );
-        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_diag_grid ) );
-        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_clas_grid ) );
-        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_feat_grid ) );
-        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET( (*this_).type_rel_grid ) );
+        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_diag_grid) );
+        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_clas_grid) );
+        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_feat_grid) );
+        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_rel_grid) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).description_label) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).description_scroll_win) );
 #endif
@@ -964,7 +1013,7 @@ void gui_main_window_private_init_simple_message_to_user( gui_main_window_t *thi
     gtk_misc_set_alignment(GTK_MISC( (*this_).message_text_label ), 0.0, 0.0 );
 #endif
 
-    (*this_).message_icon_image = gtk_image_new_from_pixbuf ( gui_resources_get_crystal_facet_uml( res ) );
+    (*this_).message_icon_image = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_crystal_facet_uml( res ) ) );
 #if ( GTK_MAJOR_VERSION >= 4 )
     /* TODO check if GtkPicture is better suited than GtkImage because of setting the size */
     // gtk_widget_set_size_request( GTK_WIDGET((*this_).message_icon_image), 32 /*=w*/ , 32 /*=h*/ );
@@ -1009,7 +1058,7 @@ void gui_main_window_private_init_search_and_sketch_area( gui_main_window_t *thi
         (*this_).search_entry = gtk_entry_new();
 
         (*this_).search_button = gtk_button_new();
-        (*this_).search_btn_icon = gtk_image_new_from_pixbuf( gui_resources_get_search_search( res ));
+        (*this_).search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_search_search( res ) ) );
         gtk_button_set_image( GTK_BUTTON((*this_).search_button), (*this_).search_btn_icon );
         gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).search_button), "Search" );
         gtk_widget_set_size_request( GTK_WIDGET((*this_).search_btn_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -1264,7 +1313,7 @@ void gui_main_window_data_changed_callback( GtkWidget *window, data_change_messa
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
