@@ -10,6 +10,10 @@
 #include <stdbool.h>
 #include <assert.h>
 
+#if ( GTK_MAJOR_VERSION < 4 )
+#define gtk_widget_set_visible(w,v) ((v)?gtk_widget_show(w):gtk_widget_hide(w))
+#endif
+
 void gui_simple_message_to_user_init ( gui_simple_message_to_user_t *this_, GtkWidget *text_label, GtkWidget *icon_image, gui_resources_t *res )
 {
     U8_TRACE_BEGIN();
@@ -56,16 +60,16 @@ void gui_simple_message_to_user_show_message ( gui_simple_message_to_user_t *thi
         case GUI_SIMPLE_MESSAGE_CONTENT_ABOUT:
         {
             utf8stringbuf_append_str( (*this_).private_temp_str,
-                                        "This is " META_INFO_PROGRAM_NAME_STR " version "
+                                      "This is " META_INFO_PROGRAM_NAME_STR " version "
                                     );
             utf8stringbuf_append_str( (*this_).private_temp_str,
-                                        META_VERSION_STR
+                                      META_VERSION_STR
                                     );
             utf8stringbuf_append_str( (*this_).private_temp_str,
-                                        "\n"
-                                        "License: " META_INFO_LICENSE_STR " / "
-                                        "Copyright: " META_INFO_COPYRIGHT_STR "\n"
-                                        "Thanks to all who have contributed to improving and deploying this tool."
+                                      "\n"
+                                      "License: " META_INFO_LICENSE_STR " / "
+                                      "Copyright: " META_INFO_COPYRIGHT_STR "\n"
+                                      "Thanks to all who have contributed to improving and deploying this tool."
                                     );
         }
         break;
@@ -187,8 +191,8 @@ void gui_simple_message_to_user_show_message ( gui_simple_message_to_user_t *thi
     U8_LOG_EVENT( utf8stringbuf_get_string( (*this_).private_temp_str ) );
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -227,8 +231,8 @@ void gui_simple_message_to_user_show_message_with_quantity ( gui_simple_message_
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -262,8 +266,8 @@ void gui_simple_message_to_user_show_message_with_line ( gui_simple_message_to_u
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -345,8 +349,8 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
     U8_TRACE_INFO_STR( "error at", name );
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -373,8 +377,8 @@ void gui_simple_message_to_user_show_message_with_names ( gui_simple_message_to_
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -408,8 +412,8 @@ void gui_simple_message_to_user_show_message_with_error ( gui_simple_message_to_
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -488,8 +492,8 @@ void gui_simple_message_to_user_show_message_with_stat ( gui_simple_message_to_u
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -532,8 +536,8 @@ void gui_simple_message_to_user_show_message_with_names_and_stat( gui_simple_mes
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -617,8 +621,8 @@ void gui_simple_message_to_user_show_error_info ( gui_simple_message_to_user_t *
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ) );
 
     /* show: */
-    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), TRUE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), TRUE );
 
     U8_TRACE_END();
 }
@@ -628,15 +632,15 @@ void gui_simple_message_to_user_hide ( gui_simple_message_to_user_t *this_ )
     U8_TRACE_BEGIN();
 
     (*this_).type_id = GUI_SIMPLE_MESSAGE_TYPE_NO_MESSAGE;
-    gtk_widget_hide( GTK_WIDGET ( (*this_).text_label ) );
-    gtk_widget_hide( GTK_WIDGET ( (*this_).icon_image ) );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).text_label ), FALSE );
+    gtk_widget_set_visible( GTK_WIDGET ( (*this_).icon_image ), FALSE );
 
     U8_TRACE_END();
 }
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
