@@ -17,11 +17,11 @@
 #include "io_element_writer.h"
 #include "io_file_format.h"
 #include "xmi/xmi_writer_pass.h"
-#include "xml/xml_writer.h"
-#include "txt/txt_writer.h"
-#include "txt/txt_icon.h"
 #include "xmi/xmi_type_converter.h"
-#include "md/md_filter.h"
+#include "format/io_xml_writer.h"
+#include "format/io_txt_writer.h"
+#include "format/io_txt_icon.h"
+#include "format/io_md_writer.h"
 #include "json/json_type_name_map.h"
 #include "data_diagram.h"
 #include "data_classifier.h"
@@ -48,11 +48,11 @@ struct document_element_writer_struct {
     json_type_name_map_t type_map;  /*!< own instance of a mapping from type ids to type names */
     data_rules_t data_rules;  /*!< own instance of uml and sysml consistency rules */
     document_link_provider_t link_provider;  /*!< own instance of a document_link_provider_t */
-    txt_icon_t txt_icon;  /*!< own instance of a txt_icon provider for relationship types */
+    io_txt_icon_t txt_icon;  /*!< own instance of a io_txt_icon provider for relationship types */
 
-    txt_writer_t txt_writer;  /*!< own instance of a txt writer */
-    xml_writer_t xml_writer;  /*!< own instance of an xml writer */
-    md_filter_t md_filter;  /*!< own instance of an md filter */
+    io_txt_writer_t txt_writer;  /*!< own instance of a txt writer */
+    io_xml_writer_t xml_writer;  /*!< own instance of an xml writer */
+    io_md_writer_t md_writer;  /*!< own instance of an md filter */
 };
 
 typedef struct document_element_writer_struct document_element_writer_t;
@@ -422,7 +422,7 @@ u8_error_t document_element_writer_write_footer( document_element_writer_t *this
 
 
 /*
-Copyright 2019-2023 Andreas Warnke
+Copyright 2019-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
