@@ -30,7 +30,7 @@ enum json_writer_max_enum {
 /*!
  *  \brief indentation
  */
-extern const char JSON_CONSTANTS_INDENT[(2*JSON_WRITER_MAX_INDENT)+sizeof('\0')];
+extern const char JSON_CONSTANTS_INDENT[(2*JSON_WRITER_MAX_INDENT)+sizeof("")];
 
 /*!
  *  \brief indentation, followed by quote
@@ -77,7 +77,7 @@ void json_writer_destroy( json_writer_t *this_ );
  *  \param text string to write
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_plain ( json_writer_t *this_, utf8string_t text );
+static inline u8_error_t json_writer_write_plain ( json_writer_t *this_, utf8string_t *text );
 
 /*!
  *  \brief writes stringview to a file, unencoded
@@ -86,7 +86,7 @@ static inline u8_error_t json_writer_write_plain ( json_writer_t *this_, utf8str
  *  \param string_view stringview to write, not 0-terminated
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_plain_view ( json_writer_t *this_, utf8stringview_t string_view );
+static inline u8_error_t json_writer_write_plain_view ( json_writer_t *this_, const utf8stringview_t *string_view );
 
 /*!
  *  \brief prints an id
@@ -115,7 +115,7 @@ u8_error_t json_writer_write_int ( json_writer_t *this_, int64_t number );
  *  \param text string to write
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_string_enc ( json_writer_t *this_, utf8string_t text );
+static inline u8_error_t json_writer_write_string_enc ( json_writer_t *this_, utf8string_t *text );
 
 /*!
  *  \brief writes a stringview to a file, json-string encoded
@@ -124,7 +124,7 @@ static inline u8_error_t json_writer_write_string_enc ( json_writer_t *this_, ut
  *  \param string_view stringview to write, not 0-terminated
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_string_view_enc ( json_writer_t *this_, utf8stringview_t string_view );
+static inline u8_error_t json_writer_write_string_view_enc ( json_writer_t *this_, const utf8stringview_t *string_view );
 
 /*!
  *  \brief writes a string to a file, encoded as list of json-strings, one string per line
@@ -133,7 +133,7 @@ static inline u8_error_t json_writer_write_string_view_enc ( json_writer_t *this
  *  \param text string to write, encoded for json comments
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_stringlist_enc ( json_writer_t *this_, utf8string_t text );
+static inline u8_error_t json_writer_write_stringlist_enc ( json_writer_t *this_, utf8string_t *text );
 
 /*!
  *  \brief writes a stringview to a file, encoded as list of json-strings, one string per line
@@ -142,7 +142,7 @@ static inline u8_error_t json_writer_write_stringlist_enc ( json_writer_t *this_
  *  \param string_view stringview to write, not 0-terminated
  *  \return U8_ERROR_NONE in case of success
  */
-static inline u8_error_t json_writer_write_stringlist_view_enc ( json_writer_t *this_, utf8stringview_t string_view );
+static inline u8_error_t json_writer_write_stringlist_view_enc ( json_writer_t *this_, const utf8stringview_t *string_view );
 
 /*!
  *  \brief writes a member name and a value integer
@@ -156,7 +156,7 @@ static inline u8_error_t json_writer_write_stringlist_view_enc ( json_writer_t *
  */
 static inline u8_error_t json_writer_write_member_int ( json_writer_t *this_,
                                                         unsigned int indent,
-                                                        utf8string_t enc_name,
+                                                        utf8string_t *enc_name,
                                                         int64_t number_value,
                                                         bool next_follows
                                                       );
@@ -173,8 +173,8 @@ static inline u8_error_t json_writer_write_member_int ( json_writer_t *this_,
  */
 static inline u8_error_t json_writer_write_member_string ( json_writer_t *this_,
                                                            unsigned int indent,
-                                                           utf8string_t enc_name,
-                                                           utf8string_t unenc_value,
+                                                           utf8string_t *enc_name,
+                                                           utf8string_t *unenc_value,
                                                            bool next_follows
                                                          );
 
@@ -191,8 +191,8 @@ static inline u8_error_t json_writer_write_member_string ( json_writer_t *this_,
  */
 static inline u8_error_t json_writer_write_member_string_array ( json_writer_t *this_,
                                                                  unsigned int indent,
-                                                                 utf8string_t enc_name,
-                                                                 utf8string_t unenc_value,
+                                                                 utf8string_t *enc_name,
+                                                                 utf8string_t *unenc_value,
                                                                  bool next_follows
                                                                );
 
@@ -202,7 +202,7 @@ static inline u8_error_t json_writer_write_member_string_array ( json_writer_t *
 
 
 /*
-Copyright 2021-2023 Andreas Warnke
+Copyright 2021-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
