@@ -14,11 +14,11 @@
  */
 
 #include "xmi/xmi_atom_writer.h"
-#include "xml/xml_writer.h"
 #include "xmi/xmi_type_converter.h"
 #include "xmi/xmi_interaction_writer.h"
+#include "xmi/xmi_writer_pass.h"
+#include "format/io_xml_writer.h"
 #include "io_file_format.h"
-#include "xmi_writer_pass.h"
 #include "io_element_writer_if.h"
 #include "io_element_writer.h"
 #include "data_diagram.h"
@@ -46,7 +46,7 @@ struct xmi_element_writer_struct {
                                                   /*!< replaces this xmi_element_writer_t in case of interactions */
 
     data_stat_t *export_stat;  /*!< pointer to external statistics object where export statistics are collected */
-    xml_writer_t xml_writer;  /*!< own instance of an xml writer */
+    io_xml_writer_t xml_writer;  /*!< own instance of an xml writer */
     xmi_atom_writer_t atom_writer;  /*!< own instance of an atom writer */
 
     xmi_type_converter_t xmi_types;  /*!< own instance of an xmi_type_converter_t */
@@ -423,7 +423,7 @@ u8_error_t xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *thi
  */
 u8_error_t xmi_element_writer_private_start_stereotype( xmi_element_writer_t *this_,
                                                         const char* profile_ns,
-                                                        const utf8stringview_t profile_type,
+                                                        const utf8stringview_t *profile_type,
                                                         const char* base_type,
                                                         data_id_t element_id
                                                       );
@@ -440,14 +440,14 @@ u8_error_t xmi_element_writer_private_start_stereotype( xmi_element_writer_t *th
  */
 u8_error_t xmi_element_writer_private_end_stereotype( xmi_element_writer_t *this_,
                                                       const char* profile_ns,
-                                                      const utf8stringview_t profile_type
+                                                      const utf8stringview_t *profile_type
                                                     );
 
 #endif  /* XMI_ELEMENT_WRITER_H */
 
 
 /*
-Copyright 2020-2023 Andreas Warnke
+Copyright 2020-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
