@@ -719,8 +719,9 @@ u8_error_t io_import_elements_sync_feature( io_import_elements_t *this_,
             }
             else  /* lifeline in paste mode */
             {
+                assert( is_lifeline );
                 data_stat_inc_count( (*this_).stat,
-                                     is_lifeline ? DATA_STAT_TABLE_LIFELINE : DATA_STAT_TABLE_FEATURE,
+                                     DATA_STAT_TABLE_LIFELINE, /* is_lifeline is true */
                                      DATA_STAT_SERIES_IGNORED
                                    );
                 U8_TRACE_INFO( "lifeline dropped at json import." );
@@ -963,7 +964,7 @@ void io_import_elements_private_report_name_differs( io_import_elements_t *this_
 
 
 /*
-Copyright 2021-2023 Andreas Warnke
+Copyright 2021-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
