@@ -299,7 +299,7 @@ u8_error_t json_token_reader_read_string_value ( json_token_reader_t *this_, utf
         universal_escaping_output_stream_flush( &esc_out );
         universal_escaping_output_stream_destroy( &esc_out );
         const u8_error_t out_err
-            = universal_memory_output_stream_write_0term( &mem_out );
+            = universal_memory_output_stream_write_0term( &mem_out, true );
         if ( 0 != out_err )
         {
             result_err = U8_ERROR_STRING_BUFFER_EXCEEDED;
@@ -493,7 +493,7 @@ u8_error_t json_token_reader_expect_eof ( json_token_reader_t *this_ )
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
