@@ -30,7 +30,7 @@ static const char * const JSON_WRITER_PRIVATE_ENCODE_JSON_STRING_ARRAYS[][2] = {
     { NULL, NULL }  /* for JSON, see rfc7159 */
 };
 
-const char JSON_CONSTANTS_INDENT[(2*JSON_WRITER_MAX_INDENT)+sizeof('\0')]
+const char JSON_CONSTANTS_INDENT[(2*JSON_WRITER_MAX_INDENT)+sizeof("")]
     = JSON_CONSTANTS_TAB JSON_CONSTANTS_TAB JSON_CONSTANTS_TAB JSON_CONSTANTS_TAB
       JSON_CONSTANTS_TAB JSON_CONSTANTS_TAB JSON_CONSTANTS_TAB;
 
@@ -102,7 +102,7 @@ u8_error_t json_writer_write_int ( json_writer_t *this_, int64_t number )
 
 
 /*
-Copyright 2021-2023 Andreas Warnke
+Copyright 2021-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
