@@ -6,6 +6,7 @@
 #include "unit/data_uuid_test.h"
 #include "unit/data_rules_test.h"
 #include "unit/data_database_listener_test.h"
+#include "unit/data_database_head_test.h"
 #include "integration/data_profile_part_test.h"
 #include "integration/data_database_reader_test.h"
 /* ctrl */
@@ -29,9 +30,9 @@
 /* gui */
 #include "unit/gui_sketch_nav_tree_test.h"
 /* io */
-#include "unit/txt_writer_test.h"
+#include "unit/io_txt_writer_test.h"
 #include "unit/json_token_reader_test.h"
-#include "unit/md_filter_test.h"
+#include "unit/io_md_writer_test.h"
 #include "unit/io_import_elements_test.h"
 #include "integration/io_data_file_test.h"
 #include "integration/io_importer_test.h"
@@ -143,6 +144,7 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, data_uuid_test_get_suite() );
         test_runner_run_suite( &runner, data_change_notifier_test_get_suite() );
         test_runner_run_suite( &runner, data_database_listener_test_get_suite() );
+        test_runner_run_suite( &runner, data_database_head_test_get_suite() );
         /* ctrl */
         /* pencil */
         test_runner_run_suite( &runner, geometry_rectangle_test_get_suite() );
@@ -154,9 +156,9 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, pencil_layout_data_test_get_suite() );
         /* gui */
         /* io */
-        test_runner_run_suite( &runner, txt_writer_test_get_suite() );
+        test_runner_run_suite( &runner, io_txt_writer_test_get_suite() );
         test_runner_run_suite( &runner, json_token_reader_test_get_suite() );
-        test_runner_run_suite( &runner, md_filter_test_get_suite() );
+        test_runner_run_suite( &runner, io_md_writer_test_get_suite() );
         test_runner_run_suite( &runner, io_import_elements_test_get_suite() );
         /* universal stream */
         test_runner_run_suite( &runner, u8__test_get_suite() );
@@ -230,7 +232,7 @@ int main (int argc, char *argv[]) {
 
 
 /*
- * Copyright 2016-2023 Andreas Warnke
+ * Copyright 2016-2024 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
