@@ -85,15 +85,15 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
            && ( result == U8_ERROR_NONE ) )
     {
         const utf8stringview_t tok = utf8stringviewtokenizer_next( tok_iterator );
-        assert( utf8stringview_get_length( tok ) > 0 );  /* otherwise this would not be a token */
+        assert( utf8stringview_get_length( &tok ) > 0 );  /* otherwise this would not be a token */
         U8_TRACE_INFO_VIEW( "token:", tok );
 
         switch ( parser_state )
         {
             case DRAW_SVG_PATH_DATA_EXPECT_COMMAND:
             {
-                const char current = *utf8stringview_get_start( tok );
-                if (( utf8stringview_equals_str( tok, "\"" ) )||( utf8stringview_equals_str( tok, "\'" ) ))
+                const char current = *utf8stringview_get_start( &tok );
+                if (( utf8stringview_equals_str( &tok, "\"" ) )||( utf8stringview_equals_str( &tok, "\'" ) ))
                 {
                     /* no subpath here to draw */
                     /* end of d attribute, back to caller */
@@ -172,8 +172,8 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COMMAND_OR_COORD_SEQ:
             {
-                const char current = *utf8stringview_get_start( tok );
-                if (( utf8stringview_equals_str( tok, "\"" ) )||( utf8stringview_equals_str( tok, "\'" ) ))
+                const char current = *utf8stringview_get_start( &tok );
+                if (( utf8stringview_equals_str( &tok, "\"" ) )||( utf8stringview_equals_str( &tok, "\'" ) ))
                 {
                     /* end of d attribute, back to caller */
                     parser_state = DRAW_SVG_PATH_DATA_EXPECT_EXIT;
@@ -265,7 +265,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -278,7 +278,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     else
                     {
                         /* U8_TRACE_INFO_INT( "line", utf8stringviewtokenizer_get_line( tok_iterator ) ); */
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     const double value_x_abs = is_absolute ? value : ( command_start_x + value );
@@ -365,17 +365,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_END_X:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -387,7 +388,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     command_end_x = is_absolute ? value : ( command_start_x + value );
@@ -418,17 +419,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_END_Y:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -440,7 +442,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     command_end_y = is_absolute ? value : ( command_start_y + value );
@@ -619,17 +621,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_CTRL1_X:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -641,7 +644,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl1_x = is_absolute ? value : ( command_start_x + value );
@@ -653,17 +656,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_CTRL1_Y:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -675,7 +679,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl1_y = is_absolute ? value : ( command_start_y + value );
@@ -687,17 +691,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_CTRL2_X:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -709,7 +714,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl2_x = is_absolute ? value : ( command_start_x + value );
@@ -721,17 +726,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_CTRL2_Y:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -743,7 +749,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl2_y = is_absolute ? value : ( command_start_y + value );
@@ -755,17 +761,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_QCTRL_X:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -777,7 +784,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl1_x = is_absolute ? value : ( command_start_x + value );
@@ -789,17 +796,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_COORD_QCTRL_Y:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -811,7 +819,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     const bool is_absolute = ( last_command <= 'Z' );
                     coord_ctrl1_y = is_absolute ? value : ( command_start_y + value );
@@ -823,17 +831,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_ARC_RX:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -845,7 +854,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     /* store value to appropriate variable */
                     arc_r_x = value;
@@ -857,17 +866,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_ARC_RY:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -879,7 +889,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     /* store value to appropriate variable */
                     arc_r_y = value;
@@ -891,17 +901,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_ARC_PHI:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -913,7 +924,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     /* store value to appropriate variable */
                     arc_phi = value * ( M_PI / 180.0 );
@@ -925,17 +936,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_ARC_LARGE:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -947,7 +959,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     /* store value to appropriate variable */
                     arc_large_arc = ( value > 0.0001 );
@@ -959,17 +971,18 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
             case DRAW_SVG_PATH_DATA_EXPECT_ARC_SWEEP:
             {
-                if ( utf8stringview_equals_str( tok, "," ) )
+                if ( utf8stringview_equals_str( &tok, "," ) )
                 {
                     /* skip */
                 }
                 else
                 {
                     /* read coordinate */
+                    /* utf8string_parse_float is faster than utf8stringview_parse_float; only it may not stop at view end but at terminating 0 after svg-path */
                     double value = 0.0;
                     unsigned int byte_length;
                     const u8_error_t float_err
-                        = utf8string_parse_float( utf8stringview_get_start( tok ), &byte_length, &value );
+                        = utf8string_parse_float( utf8stringview_get_start( &tok ), &byte_length, &value );
                     if ( float_err != U8_ERROR_NONE )
                     {
                         /* float_err could be a UTF8ERROR_NOT_FOUND or a UTF8ERROR_OUT_OF_RANGE */
@@ -981,7 +994,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
                     }
                     else
                     {
-                        assert( byte_length == utf8stringview_get_length( tok ) );
+                        assert( byte_length == utf8stringview_get_length( &tok ) );
                     }
                     /* store value to appropriate variable */
                     arc_sweep_positive = ( value > 0.0001 );
@@ -1027,7 +1040,7 @@ u8_error_t draw_svg_path_data_private_parse ( const draw_svg_path_data_t *this_,
 
 
 /*
-Copyright 2023-2023 Andreas Warnke
+Copyright 2023-2024 Andreas Warnke
     http://www.apache.org/licenses/LICENSE-2.0
 
 Licensed under the Apache License, Version 2.0 (the "License");
