@@ -25,20 +25,24 @@ static test_case_result_t testFindLast( test_fixture_t *fix );
 static test_case_result_t testCopyBuf( test_fixture_t *fix );
 static test_case_result_t testCopyStr( test_fixture_t *fix );
 static test_case_result_t testCopyWithCutUtf8( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testCopyRegion( test_fixture_t *fix );
 static test_case_result_t testReplaceRegion( test_fixture_t *fix );
 static test_case_result_t testReplaceRegionExceededRanges( test_fixture_t *fix );
 static test_case_result_t testReplaceRegionWithCutUtf8( test_fixture_t *fix );
 static test_case_result_t testReplaceRegionBuf( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 static test_case_result_t testReplaceAll( test_fixture_t *fix );
 static test_case_result_t testReplaceAllBadCases( test_fixture_t *fix );
 static test_case_result_t testReplaceAllStr( test_fixture_t *fix );
 static test_case_result_t testReplaceAllBuf( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testInsertBuf( test_fixture_t *fix );
 static test_case_result_t testInsertStr( test_fixture_t *fix );
 static test_case_result_t testDelete( test_fixture_t *fix );
 static test_case_result_t testDeleteToEnd( test_fixture_t *fix );
 static test_case_result_t testDeleteFromEnd( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 static test_case_result_t testAppendStr( test_fixture_t *fix );
 static test_case_result_t testAppendBuf( test_fixture_t *fix );
 static test_case_result_t testAppendInt( test_fixture_t *fix );
@@ -67,20 +71,24 @@ test_suite_t utf8stringbuf_test_get_suite(void)
     test_suite_add_test_case( &result, "testCopyBuf", &testCopyBuf );
     test_suite_add_test_case( &result, "testCopyStr", &testCopyStr );
     test_suite_add_test_case( &result, "testCopyWithCutUtf8", &testCopyWithCutUtf8 );
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
     test_suite_add_test_case( &result, "testCopyRegion", &testCopyRegion );
     test_suite_add_test_case( &result, "testReplaceRegion", &testReplaceRegion );
     test_suite_add_test_case( &result, "testReplaceRegionExceededRanges", &testReplaceRegionExceededRanges );
     test_suite_add_test_case( &result, "testReplaceRegionWithCutUtf8", &testReplaceRegionWithCutUtf8 );
     test_suite_add_test_case( &result, "testReplaceRegionBuf", &testReplaceRegionBuf );
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
     test_suite_add_test_case( &result, "testReplaceAll", &testReplaceAll );
     test_suite_add_test_case( &result, "testReplaceAllBadCases", &testReplaceAllBadCases );
     test_suite_add_test_case( &result, "testReplaceAllStr", &testReplaceAllStr );
     test_suite_add_test_case( &result, "testReplaceAllBuf", &testReplaceAllBuf );
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
     test_suite_add_test_case( &result, "testInsertBuf", &testInsertBuf );
     test_suite_add_test_case( &result, "testInsertStr", &testInsertStr );
     test_suite_add_test_case( &result, "testDelete", &testDelete );
     test_suite_add_test_case( &result, "testDeleteToEnd", &testDeleteToEnd );
     test_suite_add_test_case( &result, "testDeleteFromEnd", &testDeleteFromEnd );
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
     test_suite_add_test_case( &result, "testAppendStr", &testAppendStr );
     test_suite_add_test_case( &result, "testAppendBuf", &testAppendBuf );
     test_suite_add_test_case( &result, "testAppendInt", &testAppendInt );
@@ -755,6 +763,7 @@ static test_case_result_t testFindLast( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testCopyRegion( test_fixture_t *fix )
 {
     utf8error_t error;
@@ -874,7 +883,9 @@ static test_case_result_t testCopyRegion( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testReplaceRegion( test_fixture_t *fix )
 {
     utf8error_t error;
@@ -928,7 +939,9 @@ static test_case_result_t testReplaceRegion( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 127, dynTestArr1[14] );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testReplaceRegionExceededRanges( test_fixture_t *fix )
 {
     utf8error_t error;
@@ -1002,7 +1015,9 @@ static test_case_result_t testReplaceRegionExceededRanges( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 127, dynTestArr1[14] );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testReplaceRegionWithCutUtf8( test_fixture_t *fix )
 {
     utf8error_t error;
@@ -1038,7 +1053,9 @@ static test_case_result_t testReplaceRegionWithCutUtf8( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 127, dynTestArr1[14] );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testReplaceRegionBuf( test_fixture_t *fix )
 {
     /* utf8stringbuf_replace_region_by_buf is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1057,6 +1074,7 @@ static test_case_result_t testReplaceRegionBuf( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
 static test_case_result_t testReplaceAll ( test_fixture_t *fix )
 {
@@ -1101,7 +1119,8 @@ static test_case_result_t testReplaceAll ( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
     /* shrink because performance hungry function */
-    utf8stringbuf_delete_to_end( (*fix).mega_byte_buf, 20000 );
+    (*fix).mega_byte_arr[20000] = '\0';
+    /* utf8stringbuf_delete_to_end( (*fix).mega_byte_buf, 20000 ); */
 
     /* shrink at each replacement */
     error = utf8stringbuf_replace_all( (*fix).mega_byte_buf, &SHRINK_DUPLICATES_EXCEPT_Z );
@@ -1260,6 +1279,7 @@ static test_case_result_t testReplaceAllBuf( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testInsertBuf( test_fixture_t *fix )
 {
     /* utf8stringbuf_insert_buf is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1278,7 +1298,9 @@ static test_case_result_t testInsertBuf( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testInsertStr( test_fixture_t *fix )
 {
     /* utf8stringbuf_insert_str is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1295,7 +1317,9 @@ static test_case_result_t testInsertStr( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testDelete( test_fixture_t *fix )
 {
     /* utf8stringbuf_delete is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1312,7 +1336,9 @@ static test_case_result_t testDelete( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testDeleteFromEnd( test_fixture_t *fix )
 {
     /* utf8stringbuf_delete is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1329,7 +1355,9 @@ static test_case_result_t testDeleteFromEnd( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testDeleteToEnd( test_fixture_t *fix )
 {
     /* utf8stringbuf_delete is just a wrapper around utf8stringbuf_replace_region_by_str */
@@ -1346,6 +1374,7 @@ static test_case_result_t testDeleteToEnd( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 
 static test_case_result_t testAppendStr( test_fixture_t *fix )
 {
@@ -1601,37 +1630,39 @@ static test_case_result_t testAppendView( test_fixture_t *fix )
     utf8stringbuf_t dynTestBuf1 = UTF8STRINGBUF(dynTestArr1);
 
     /* check utf8stringbuf_append_wstr */
-    utf8stringview_t view1 = UTF8STRINGVIEW_STR( "lo" );
-    utf8stringbuf_copy_view( dynTestBuf1, UTF8STRINGVIEW_STR( "Hel" ) );
-    error = utf8stringbuf_append_view( dynTestBuf1, view1 );
+    const utf8stringview_t view0 = UTF8STRINGVIEW_STR( "Hel" );
+    const utf8stringview_t view1 = UTF8STRINGVIEW_STR( "lo" );
+    utf8stringbuf_copy_view( dynTestBuf1, &view0 );
+    error = utf8stringbuf_append_view( dynTestBuf1, &view1 );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "Hello" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
     /* check utf8stringbuf_append_view with multibyte */
-    utf8stringview_t view2 = UTF8STRINGVIEW_STR( "e\xE2\x82\xAC" );
+    const utf8stringview_t view2 = UTF8STRINGVIEW_STR( "e\xE2\x82\xAC" );
     utf8stringbuf_copy_str( dynTestBuf1, "H" );
-    error = utf8stringbuf_append_view( dynTestBuf1, view2 );
+    error = utf8stringbuf_append_view( dynTestBuf1, &view2 );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "He\xE2\x82\xAC" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
     /* check utf8stringbuf_append_view with truncation */
     utf8stringbuf_copy_str( dynTestBuf1, "He" );
-    error = utf8stringbuf_append_view( dynTestBuf1, view2 );
+    error = utf8stringbuf_append_view( dynTestBuf1, &view2 );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_TRUNCATED, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "Hee" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
     utf8stringbuf_copy_str( dynTestBuf1, "Hello" );
-    error = utf8stringbuf_append_view( dynTestBuf1, view2 );
+    error = utf8stringbuf_append_view( dynTestBuf1, &view2 );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_TRUNCATED, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "Hello" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
     /* check utf8stringbuf_append_view with NULL */
+    const utf8stringview_t no_view = UTF8STRINGVIEW_EMPTY;
     utf8stringbuf_copy_str( dynTestBuf1, "He" );
-    error = utf8stringbuf_append_view( dynTestBuf1, UTF8STRINGVIEW_NULL );
+    error = utf8stringbuf_append_view( dynTestBuf1, &no_view );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "He" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
@@ -1771,7 +1802,7 @@ static test_case_result_t testGetEnd( test_fixture_t *fix )
 
 
 /*
- * Copyright 2012-2023 Andreas Warnke
+ * Copyright 2012-2024 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1785,5 +1816,3 @@ static test_case_result_t testGetEnd( test_fixture_t *fix )
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-
