@@ -17,8 +17,6 @@ static test_case_result_t testNoSeparatorUseCase( test_fixture_t *fix );
 static test_case_result_t testEmptyElementsUseCase( test_fixture_t *fix );
 static test_case_result_t testEmptyListUseCase( test_fixture_t *fix );
 static test_case_result_t testEmptySeparatorUseCase( test_fixture_t *fix );
-static test_case_result_t testNullListUseCase( test_fixture_t *fix );
-static test_case_result_t testNullSeparatorUseCase( test_fixture_t *fix );
 
 test_suite_t utf8stringviewiterator_test_get_suite(void)
 {
@@ -29,8 +27,6 @@ test_suite_t utf8stringviewiterator_test_get_suite(void)
     test_suite_add_test_case( &result, "testEmptyElementsUseCase", &testEmptyElementsUseCase );
     test_suite_add_test_case( &result, "testEmptyListUseCase", &testEmptyListUseCase );
     test_suite_add_test_case( &result, "testEmptySeparatorUseCase", &testEmptySeparatorUseCase );
-    test_suite_add_test_case( &result, "testNullListUseCase", &testNullListUseCase );
-    test_suite_add_test_case( &result, "testNullSeparatorUseCase", &testNullSeparatorUseCase );
     return result;
 }
 
@@ -51,28 +47,28 @@ static test_case_result_t testStandardUseCase( test_fixture_t *fix )
 
     /* init */
     utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), ", " );
+    utf8stringviewiterator_init( &it, &UTF8STRINGVIEW_STR( my_list ), ", " );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 3, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 3, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+5), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 2, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+5), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 2, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( false, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     /* finish */
     utf8stringviewiterator_destroy( &it );
@@ -87,21 +83,21 @@ static test_case_result_t testNoSeparatorUseCase( test_fixture_t *fix )
 
     /* init */
     utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), ",, 24567" );
+    utf8stringviewiterator_init( &it, &UTF8STRINGVIEW_STR( my_list ), ",, 24567" );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( strlen( my_list ), utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( strlen( my_list ), utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( false, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     /* finish */
     utf8stringviewiterator_destroy( &it );
@@ -116,49 +112,49 @@ static test_case_result_t testEmptyElementsUseCase( test_fixture_t *fix )
 
     /* init */
     utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), "," );
+    utf8stringviewiterator_init( &it, &UTF8STRINGVIEW_STR( my_list ), "," );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+0), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+1), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 2, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+1), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 2, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+4), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+4), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+5), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 3, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+5), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 3, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( (my_list+9), utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( (my_list+9), utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( false, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     /* finish */
     utf8stringviewiterator_destroy( &it );
@@ -173,20 +169,20 @@ static test_case_result_t testEmptyListUseCase( test_fixture_t *fix )
 
     /* init */
     utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), "," );
+    utf8stringviewiterator_init( &it, &UTF8STRINGVIEW_STR( my_list ), "," );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( false, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     /* finish */
     utf8stringviewiterator_destroy( &it );
@@ -201,77 +197,21 @@ static test_case_result_t testEmptySeparatorUseCase( test_fixture_t *fix )
 
     /* init */
     utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), "" );  /* unspecified case */
+    utf8stringviewiterator_init( &it, &UTF8STRINGVIEW_STR( my_list ), "" );  /* unspecified case */
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( true, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( my_list, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( strlen( my_list ), utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( my_list, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( strlen( my_list ), utf8stringview_get_length( &next ) );
 
     has_next = utf8stringviewiterator_has_next( &it );
     TEST_EXPECT_EQUAL_INT( false, has_next );
 
     next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
-
-    /* finish */
-    utf8stringviewiterator_destroy( &it );
-    return TEST_CASE_RESULT_OK;
-}
-
-static test_case_result_t testNullListUseCase( test_fixture_t *fix )
-{
-    bool has_next;
-    utf8stringview_t next;
-
-    /* init */
-    utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_NULL, "" );  /* unspecified case */
-
-    has_next = utf8stringviewiterator_has_next( &it );
-    TEST_EXPECT_EQUAL_INT( true, has_next );
-
-    next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
-
-    has_next = utf8stringviewiterator_has_next( &it );
-    TEST_EXPECT_EQUAL_INT( false, has_next );
-
-    next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
-
-    /* finish */
-    utf8stringviewiterator_destroy( &it );
-    return TEST_CASE_RESULT_OK;
-}
-
-static test_case_result_t testNullSeparatorUseCase( test_fixture_t *fix )
-{
-    bool has_next;
-    utf8stringview_t next;
-    static const char *const my_list = "1,2,3";
-
-    /* init */
-    utf8stringviewiterator_t it;
-    utf8stringviewiterator_init( &it, UTF8STRINGVIEW_STR( my_list ), NULL );  /* unspecified case */
-
-    has_next = utf8stringviewiterator_has_next( &it );
-    TEST_EXPECT_EQUAL_INT( true, has_next );
-
-    next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( my_list, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( strlen( my_list ), utf8stringview_get_length( next ) );
-
-    has_next = utf8stringviewiterator_has_next( &it );
-    TEST_EXPECT_EQUAL_INT( false, has_next );
-
-    next = utf8stringviewiterator_next( &it );
-    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( next ) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( next ) );
+    TEST_EXPECT_EQUAL_PTR( NULL, utf8stringview_get_start( &next ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8stringview_get_length( &next ) );
 
     /* finish */
     utf8stringviewiterator_destroy( &it );
@@ -280,7 +220,7 @@ static test_case_result_t testNullSeparatorUseCase( test_fixture_t *fix )
 
 
 /*
- * Copyright 2021-2023 Andreas Warnke
+ * Copyright 2021-2024 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
